Package: BSET
Type: Package
Title: A Bayesian Surrogate Evaluation Test
Version: 1.0
Date: 2026-05-15
Authors@R: c(
    person("Pietro", "Carlotti", role = c("aut", "cre"),
           email = "pietro.carlotti@utexas.edu"),
    person("Layla", "Parast", role = "aut",
           email = "parast@austin.utexas.edu"))
Description: An implementation of the Bayesian Surrogate Evaluation Test
    (BSET) for assessing the validity of surrogate markers in clinical
    trials. Provides hypothesis testing tools to evaluate whether a
    surrogate can reliably estimate the causal effect of a treatment on a
    primary outcome. Implements the imputation-based Bayesian methodology
    of Carlotti and Parast (2026) <doi:10.48550/arXiv.2603.14381>,
    extending the frequentist rank-based approach of Parast et al. (2024)
    <doi:10.1093/biomtc/ujad035>. Addresses key limitations of the
    frequentist method, including the lack of causal interpretability and
    the inability to adjust for covariates in the estimation process.
License: GPL-3
URL: https://pietrocarlotti.github.io/BSET/,
        https://github.com/PietroCarlotti/BSET
BugReports: https://github.com/PietroCarlotti/BSET/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Imports: rstan, ggplot2, future, parallel, mvtnorm, dplyr,
        SurrogateRank, Rdpack, rlang
RdMacros: Rdpack
Suggests: knitr, rmarkdown, bookdown,
VignetteBuilder: knitr, bookdown
Depends: R (>= 3.5)
NeedsCompilation: no
Packaged: 2026-05-18 18:13:14 UTC; pc29642
Author: Pietro Carlotti [aut, cre],
  Layla Parast [aut]
Maintainer: Pietro Carlotti <pietro.carlotti@utexas.edu>
Repository: CRAN
Date/Publication: 2026-05-22 09:32:08 UTC
Built: R 4.5.2; ; 2026-05-22 11:23:07 UTC; unix

Package: BSET
Type: Package
Title: A Bayesian Surrogate Evaluation Test
Version: 1.0
Date: 2026-05-15
Authors@R: c(
    person("Pietro", "Carlotti", role = c("aut", "cre"),
           email = "pietro.carlotti@utexas.edu"),
    person("Layla", "Parast", role = "aut",
           email = "parast@austin.utexas.edu"))
Description: An implementation of the Bayesian Surrogate Evaluation Test
    (BSET) for assessing the validity of surrogate markers in clinical
    trials. Provides hypothesis testing tools to evaluate whether a
    surrogate can reliably estimate the causal effect of a treatment on a
    primary outcome. Implements the imputation-based Bayesian methodology
    of Carlotti and Parast (2026) <doi:10.48550/arXiv.2603.14381>,
    extending the frequentist rank-based approach of Parast et al. (2024)
    <doi:10.1093/biomtc/ujad035>. Addresses key limitations of the
    frequentist method, including the lack of causal interpretability and
    the inability to adjust for covariates in the estimation process.
License: GPL-3
URL: https://pietrocarlotti.github.io/BSET/,
        https://github.com/PietroCarlotti/BSET
BugReports: https://github.com/PietroCarlotti/BSET/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Imports: rstan, ggplot2, future, parallel, mvtnorm, dplyr,
        SurrogateRank, Rdpack, rlang
RdMacros: Rdpack
Suggests: knitr, rmarkdown, bookdown,
VignetteBuilder: knitr, bookdown
Depends: R (>= 3.5)
NeedsCompilation: no
Packaged: 2026-05-18 18:13:14 UTC; pc29642
Author: Pietro Carlotti [aut, cre],
  Layla Parast [aut]
Maintainer: Pietro Carlotti <pietro.carlotti@utexas.edu>
Repository: CRAN
Date/Publication: 2026-05-22 09:32:08 UTC
Built: R 4.6.0; ; 2026-05-22 12:02:44 UTC; unix

# Generated by roxygen2: do not edit by hand

export(BSET)
export(Bayesian_test)
export(DGP_X_Gaussian)
export(DGP_X_binary)
export(DGP_no_X)
export(compute_BF_distribution)
export(compute_V_S_star)
export(compute_delta)
export(compute_estimands_Carlotti_and_Parast_2026)
export(compute_estimands_Parast_et_al_2024)
export(compute_theta)
export(frequentist_test)
importFrom(Rdpack,reprompt)
importFrom(SurrogateRank,test.surrogate)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(mvtnorm,rmvnorm)
importFrom(rlang,.data)
importFrom(stats,dbinom)
importFrom(stats,pbeta)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,uniroot)
importFrom(stats,wilcox.test)

# BSET <img src="man/figures/logo.png" align="right" height="220" alt="BSET hex logo" />

<!-- badges: start -->

<!-- badges: end -->

`BSET` (Bayesian Surrogate Evaluation Test) is an `R` package for
assessing the validity of surrogate markers in clinical trials. It
provides hypothesis testing tools to evaluate whether a surrogate can
reliably estimate the causal effect of a treatment on a primary outcome.
The package implements the imputation-based Bayesian methodology of
Carlotti and Parast (2026), extending the frequentist rank-based
approach of Parast et al. (2024). BSET addresses key limitations of the
frequentist method, including the lack of causal interpretability and
the inability to adjust for covariates in the estimation process.

The package supports Bayesian testing both with and without baseline
covariates. Additionally, it includes comprehensive simulation suites to
replicate studies from both papers, enabling performance comparisons
between Bayesian and frequentist approaches across diverse clinical
scenarios.

For a detailed walkthrough and examples of the imputation-based
methodology, please visit the [BSET
Tutorial](https://pietrocarlotti.github.io/BSET/articles/BSET_tutorial.html).

## Citation

If you use this package, please cite:

Carlotti, P. and Parast, L. (2026). A Bayesian Critique of Rank-Based Methods for Surrogate Marker Evaluation. *arXiv preprint arXiv:2603.14381*.

## Replication

All code and instructions needed to replicate the results presented in
the paper can be found in the `replication/` folder.

## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ----install-BSET-------------------------------------------------------------
# install.packages("pak")
# pak::pak("PietroCarlotti/BSET")

## ----packages, message=FALSE, warning=FALSE-----------------------------------
library(ggplot2)
library(dplyr)

## ----quick-start-data---------------------------------------------------------
# Set the random seed for reproducibility
set.seed(1234)

# Sample size
n <- 50

# Binary covariate
X <- rbinom(n, 1, 0.5)

# Treatment assignment
Z <- rbinom(n, 1, 0.5)

# Primary outcome
Y <- 2 * Z -3 * X + rnorm(n)

# Surrogate outcome
S <- Y + rnorm(n)

df <- data.frame(
  Y = Y,
  S = S,
  Z = Z,
  X = X
)

## ----quick-start-no-X, eval=FALSE---------------------------------------------
# result_no_X <- BSET::BSET(
#   data = df,
#   Y = "Y",
#   S = "S",
#   Z = "Z",
#   seed = 123,
#   plot = TRUE
# )
# result_no_X$theta_posterior_plot

## ----quick-start-no-X-show, echo=FALSE, out.width="100%", fig.align='center', fig.cap="Posterior distribution of $\\theta$ from `BSET` without covariates. Dashed lines show estimated quantities: the Bayesian 95\\% credible interval upper bound and threshold $\\eta$ (<span style='color:#0072B2'>blue shades</span>), and the frequentist 95\\% confidence interval upper bound and threshold $\\varepsilon$ (<span style='color:#D55E00'>orange shades</span>)."----
knitr::include_graphics("BSET_quick_start_no_X_plot.png")

## ----quick-start-X, eval=FALSE------------------------------------------------
# result_X <- BSET::BSET(
#   data = df,
#   Y = "Y",
#   S = "S",
#   Z = "Z",
#   X = "X",
#   seed = 123,
#   plot = TRUE
# )
# result_X$theta_posterior_plot

## ----quick-start-X-show, echo=FALSE, out.width="100%", fig.align='center', fig.cap="Posterior distribution of $\\theta$ from `BSET`, adjusted for a baseline covariate. Dashed lines show estimated quantities: the Bayesian 95\\% credible interval upper bound and threshold $\\eta$ (<span style='color:#0072B2'>blue shades</span>), and the frequentist 95\\% confidence interval upper bound and threshold $\\varepsilon$ (<span style='color:#D55E00'>orange shades</span>)."----
knitr::include_graphics("BSET_quick_start_X_plot.png")

## ----set-seed-----------------------------------------------------------------
# Set the random seed for reproducibility
set.seed(1234)

# Sample size and treatment assignment probability used throughout
n <- 50
p <- 0.5

## ----generate-data-no-X-------------------------------------------------------
# Mean vector of potential outcomes for the primary outcome and the surrogate
mu_star <- c(6, 6, 2.5, 2.5)

# Covariance matrix of potential outcomes for the primary outcome and the surrogate
Sigma_star <- kronecker(
  diag(2),
  matrix(
    data = c(3, 3,
             3, 3.1),
    nrow = 2,
    ncol = 2)
)

# Generate the data
data_no_X <- BSET::DGP_no_X(
  n = n,
  p = p,
  mu_star = mu_star,
  Sigma_star = Sigma_star,
  model = "Gaussian"
)

## ----generate-data-X----------------------------------------------------------
# Binary covariate probability
q <- 0.5

# Mean vector for potential outcomes when X = 0 and when X = 1
mu_0 <- c(5, 5, 0, 0)
mu_1 <- c(5, -5, 0, -10)

# Covariance matrix for potential outcomes when X = 0 and when X = 1
Sigma_0 <- kronecker(
  diag(2),
  matrix(
    data = c(1, 1,
             1, 2),
    nrow = 2,
    ncol = 2)
  )

Sigma_1 <- kronecker(
  diag(2),
  matrix(
    data = c(1, 1,
             1, 2),
    nrow = 2,
    ncol = 2)
  )

# Generate the data
data_X <- BSET::DGP_X_binary(
  n = n,
  p = p,
  q = q,
  mu_0 = mu_0,
  mu_1 = mu_1,
  Sigma_0 = Sigma_0,
  Sigma_1 = Sigma_1
  )

## ----compute-delta-theta-no-X-------------------------------------------------
# Compute delta
delta_no_X <- BSET::compute_delta(MC_data = data_no_X)

# Compute theta
theta_no_X <- BSET::compute_theta(MC_data = data_no_X)

## ----compute-delta-theta-X----------------------------------------------------
# Compute delta
delta_X <- BSET::compute_delta(MC_data = data_X)

# Compute theta
theta_X <- BSET::compute_theta(MC_data = data_X)

## ----delta-theta-table, echo=FALSE--------------------------------------------
delta_theta_table <- data.frame(
  Setting = c("No X (Perfect Surrogate)", "Binary X"),
  "$\\widehat{\\delta}$" = c(delta_no_X$delta, delta_X$delta),
  "$\\widehat{\\theta}$" = c(theta_no_X$theta, theta_X$theta),
  check.names = FALSE 
)

knitr::kable(
  delta_theta_table, 
  caption = "Estimated values of $\\delta$ and $\\theta$ in the two settings.",
  escape = FALSE,
  booktabs = TRUE,
  align = "ccc",
  digits = 3
)

## ----compute-delta-theta-true-code, eval=FALSE--------------------------------
# # Compute Monte Carlo estimands (based on 1,000,000 samples) — this is slow
# estimands_Parast_et_al_2024 <- BSET::compute_estimands_Parast_et_al_2024(n_MC = 1000000)
# estimands_Carlotti_and_Parast_2026 <- BSET::compute_estimands_Carlotti_and_Parast_2026(n_MC = 1000000)

## ----compute-delta-theta-true-------------------------------------------------
# Load precomputed Monte Carlo estimands (based on 1,000,000 samples)
estimands_Parast_et_al_2024 <- BSET::estimands_Parast_et_al_2024
estimands_Carlotti_and_Parast_2026 <- BSET::estimands_Carlotti_and_Parast_2026

## ----estimands-Parast-et-al-2024, echo=FALSE----------------------------------
estimands_Parast_et_al_2024_table <- data.frame(
  Setting = c("Useless surrogate", "Perfect surrogate", "Imperfect surrogate", "Misspecified model"),
  "$\\delta$" = estimands_Parast_et_al_2024$delta_MC,
  "$\\theta$" = estimands_Parast_et_al_2024$theta_MC,
  check.names = FALSE
)

knitr::kable(
  estimands_Parast_et_al_2024_table,
  caption = "Monte Carlo estimates of $\\delta$ and $\\theta$ for the simulation settings considered in Parast et al. (2024).",
  booktabs = TRUE,
  align = "ccc",
  digits = 3
)

## ----estimands-Carlotti-and-Parast-2026, echo=FALSE---------------------------
estimands_Carlotti_and_Parast_2026_table <- data.frame(
  Setting = c("Perfect surrogate"),
  "$\\delta$" = estimands_Carlotti_and_Parast_2026$delta_MC,
  "$\\theta$" = estimands_Carlotti_and_Parast_2026$theta_MC,
  check.names = FALSE
)

knitr::kable(
  estimands_Carlotti_and_Parast_2026_table,
  caption = "Monte Carlo estimates of $\\delta$ and $\\theta$ for the simulation settings considered in Carlotti and Parast (2026).",
  booktabs = TRUE,
  align = "ccc",
  digits = 3
)

## ----compute-BF-distribution--------------------------------------------------
# Hypothesized value of V_S under the null
V_S_zero <- 0.5

# Prior parameters for the Beta distribution
a <- 1
b <- 1

# Alternative hypothesis for the Bayes factor
BF_alternative <- "greater"

# Compute the distribution of the Bayes factor
BF_distribution <- BSET::compute_BF_distribution(
  n = n,
  V_S_true = V_S_zero,
  V_S_zero = V_S_zero,
  a = a,
  b = b,
  BF_alternative = BF_alternative
)

## ----BF-distribution-plot, echo=FALSE, fig.width=8, fig.height=4.5, fig.align='center', fig.cap="Distribution of the Bayes factor under the null hypothesis $V_S = 0.5$."----
# Log transform the Bayes factor
BF_distribution$log_BF_values <- log(BF_distribution$BF_values)

ggplot(BF_distribution, aes(x = log_BF_values, y = BF_PMF)) +
  geom_col(fill = "steelblue", width = 0.07) +
  labs(
    x = expression(log(BF[n])),
    y = "PMF"
  ) +
  theme_minimal()

## ----compute-BF-alpha---------------------------------------------------------
# Type I error rate
alpha <- 0.05

# Compute the critical value of the Bayes factor corresponding to alpha
BF_alpha <- BF_distribution %>%
    dplyr::filter(BF_CDF >= 1 - alpha) %>%
    dplyr::slice(1) %>%
    dplyr::pull(BF_values)

## ----compute-V_S-star---------------------------------------------------------
# Type II error rate
beta <- 0.2

# Compute the value of v_S that satisfies the power constraint
V_S_star <- BSET::compute_V_S_star(
  n = n,
  alpha = alpha,
  beta = beta,
  V_S_zero = V_S_zero,
  a = a,
  b = b,
  BF_alternative = BF_alternative,
  root_tolerance = 1e-16
)$V_S_star

## ----compute-eta--------------------------------------------------------------
# Hypothesized value of the treatment effect on the primary outcome
v_Y <- estimands_Parast_et_al_2024$V_Y_MC[2]

# Compute the validation threshold eta
eta <- max(v_Y - V_S_star, 0)

## ----BSET-no-X-data-----------------------------------------------------------
# Prepare the data for BSET (no covariates)
BSET_no_X_data <- data.frame(
  Y = data_no_X$P_observed[, "Y"],
  S = data_no_X$P_observed[, "S"],
  Z = data_no_X$Z 
)

## ----BSET-no-X-posterior-sampling-parameters----------------------------------
# Posterior sampling parameters
n_chains <- 2
n_iter <- 2000
burn_in_ratio <- 0.25

## ----BSET-no-X-prior-parameters-----------------------------------------------
# Prior parameters
mu_0 <- rep(0, 4)
Sigma_0 <- diag(4)
s <- rep(1, 4)
tau <- 1

## ----BSET-no-X, eval=FALSE----------------------------------------------------
# # Run the BSET procedure without adjusting for covariates
# BSET_no_X_results <- BSET::BSET(
#   data = BSET_no_X_data,
#   Y = "Y",
#   S = "S",
#   Z = "Z",
#   delta_true = estimands_Parast_et_al_2024$delta_MC[2],
#   theta_true = estimands_Parast_et_al_2024$theta_MC[2],
#   seed = 123,
#   n_chains = n_chains,
#   n_iter = n_iter,
#   burn_in_ratio = burn_in_ratio,
#   a = a,
#   b = b,
#   alpha = alpha,
#   beta = beta,
#   V_S_zero = V_S_zero,
#   BF_alternative = BF_alternative,
#   root_tolerance = 1e-16,
#   mu_0 = mu_0,
#   Sigma_0 = Sigma_0,
#   s = s,
#   tau = tau,
#   plot = TRUE,
#   mute = TRUE,
#   parallel = TRUE
# )

## ----BSET-no-X-load, include=FALSE--------------------------------------------

## ----BSET-no-X-plot, echo=FALSE, out.width="100%", fig.align='center', fig.cap="Posterior distribution of $\\theta$ from the BSET procedure without adjusting for covariates. Dashed lines show estimated quantities: the Bayesian 95\\% credible interval upper bound and threshold $\\eta$ (<span style='color:#0072B2'>blue shades</span>), and the frequentist 95\\% confidence interval upper bound and threshold $\\varepsilon$ (<span style='color:#D55E00'>orange shades</span>). Solid lines show the true values of $\\theta$ (<span style='color:#551A8B'>purple</span>) and $\\delta$ (<span style='color:#CC79A7'>pink</span>)."----
knitr::include_graphics("BSET_no_X_plot.png")

## ----BSET-X-data--------------------------------------------------------------
# Prepare the data for BSET (with covariates)
BSET_X_data <- data.frame(
  Y = data_X$P_observed[, "Y"],
  S = data_X$P_observed[, "S"],
  Z = data_X$Z,
  X = data_X$X
)

## ----BSET-X-prior-parameters--------------------------------------------------
# Prior parameters for the regression coefficients of the potential outcomes on the covariates
d <- 2
mu_beta <- rep(0, d)
Sigma_beta <- 10*diag(d)

## ----BSET-X, eval=FALSE-------------------------------------------------------
# # Run the BSET procedure adjusting for covariates
# BSET_X_results <- BSET::BSET(
#   data = BSET_X_data,
#   Y = "Y",
#   S = "S",
#   Z = "Z",
#   X = "X",
#   delta_true = estimands_Carlotti_and_Parast_2026$delta_MC[1],
#   theta_true = estimands_Carlotti_and_Parast_2026$theta_MC[1],
#   seed = 123,
#   n_chains = n_chains,
#   n_iter = n_iter,
#   burn_in_ratio = burn_in_ratio,
#   a = a,
#   b = b,
#   alpha = alpha,
#   beta = beta,
#   V_S_zero = V_S_zero,
#   BF_alternative = BF_alternative,
#   root_tolerance = 1e-16,
#   mu_beta = mu_beta,
#   Sigma_beta = Sigma_beta,
#   s = s,
#   tau = tau,
#   plot = TRUE,
#   mute = TRUE,
#   parallel = TRUE
# )

## ----BSET-X-load, include=FALSE-----------------------------------------------

## ----BSET-X-plot, echo=FALSE, out.width="100%", fig.align='center', fig.cap="Posterior distribution of $\\theta$ from the BSET procedure adjusting for covariates. Dashed lines show estimated quantities: the Bayesian 95\\% credible interval upper bound and threshold $\\eta$ (<span style='color:#0072B2'>blue shades</span>), and the frequentist 95\\% confidence interval upper bound and threshold $\\varepsilon$ (<span style='color:#D55E00'>orange shades</span>). Solid lines show the true values of $\\theta$ (<span style='color:#551A8B'>purple</span>) and $\\delta$ (<span style='color:#CC79A7'>pink</span>)."----
knitr::include_graphics("BSET_X_plot.png")

#' Bayesian Test from Carlotti and Parast (2026)
#'
#' This function performs a Bayesian test for surrogate evaluation based on the
#' imputation-based methodology of \insertCite{carlotti2026bayesian;textual}{BSET}. It calculates
#' credible intervals, the \eqn{\eta} threshold used, and determines if the
#' surrogate is valid.
#' This function is generally not intended to be called directly by the user
#' and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
#'
#' @param P_MCMC A three-dimensional array of potential outcomes obtained via MCMC sampling with dimensions \code{[n_subjects, variables, n_samples]}. The variables should correspond to \eqn{(Y_1, S_1, Y_0, S_0)}.
#' @param alpha Numeric. Significance level for the credible interval (default is 0.05).
#' @param V_S_star Numeric. The value of \eqn{v_S} that satisfies the power constraint for the surrogate validation test.
#' @param theta_true Numeric (optional). The true value of \eqn{\eta}, used to calculate frequentist coverage during simulations.
#' @param V_Y_true Numeric (optional). The true value of \eqn{V_Y}, used to calculate the surrogate validation threshold \eqn{\eta} during simulations. If not provided, it will be estimated from the MCMC samples.
#' @return A list containing:
#' \itemize{
#'   \item \code{V_Y_MCMC}: Posterior draws for \eqn{V_Y}.
#'   \item \code{V_S_MCMC}: Posterior draws for \eqn{V_S}.
#'   \item \code{theta_MCMC}: Posterior draws for \eqn{\theta = V_Y - V_S}.
#'   \item \code{CI}: The calculated credible interval for \eqn{\theta}.
#'   \item \code{threshold}: The \eqn{\eta} threshold value used in the test.
#'   \item \code{coverage}: Logical indicating if \code{theta_true} falls within the \code{CI} (if \code{theta_true} is provided).
#'   \item \code{power}: Logical indicating if the upper bound of \code{CI} is below \code{threshold}, which indicates that the test identifies the surrogate as valid.
#' }
#' @references
#' \insertRef{carlotti2026bayesian}{BSET}
#' @export
Bayesian_test <- function(P_MCMC, alpha = 0.05, V_S_star, theta_true = NULL, V_Y_true = NULL) {
  
  # Determine number of samples iterations
  n_samples <- dim(P_MCMC)[3]
  
  # Set column names for clarity
  colnames(P_MCMC) <- c("Y1", "S1", "Y0", "S0")
  
  # Initialize vectors to store posterior draws
  V_Y_MCMC <- numeric(n_samples)
  V_S_MCMC <- numeric(n_samples)
  theta_MCMC <- numeric(n_samples)
  
  # Loop over samples
  for (k in 1:n_samples) {
    V_Y_MCMC[k] <- mean(P_MCMC[, "Y1", k] > P_MCMC[, "Y0", k])
    V_S_MCMC[k] <- mean(P_MCMC[, "S1", k] > P_MCMC[, "S0", k])
    theta_MCMC[k] <- V_Y_MCMC[k] - V_S_MCMC[k]
  }
  
  # Bayesian credible interval
  Bayes_CI <- c(-1, stats::quantile(theta_MCMC, probs = 1 - alpha))
  
  # Calculations
  Bayes_threshold <- max(mean(V_Y_MCMC) - V_S_star, 0)
  Bayes_power <- Bayes_CI[2] < Bayes_threshold
  
  if (!is.null(theta_true)) {
    Bayes_coverage <- theta_true < Bayes_CI[2]
  } else {
    Bayes_coverage <- NA
  }
  
  # Return as a list
  list(
    V_Y_MCMC = V_Y_MCMC,
    V_S_MCMC = V_S_MCMC,
    theta_MCMC = theta_MCMC,
    CI = Bayes_CI,
    threshold = Bayes_threshold,
    coverage = Bayes_coverage,
    power = Bayes_power
  )
}

#' Monte Carlo Computation of the Parameter \eqn{\delta} from Parast et al. (2024)
#'
#' This function implements a Monte Carlo approach to estimate the parameter
#' \eqn{\delta} from \insertCite{parast2024rank;textual}{BSET}. This parameter represents the
#' difference in treatment effects between the primary and surrogate outcomes,
#' both measured using the Mann-Whitney statistic.
#' 
#' @details The function processes data from a chosen data generating process,
#' computing the Mann-Whitney U statistic for both the primary outcome \eqn{Y}
#' and the surrogate \eqn{S}:
#' \deqn{\hat{U}_Y = \frac{1}{n_1 n_0} \sum\limits_{i:Z_i=1} \sum\limits_{j:Z_j=0} I(Y_i > Y_j),}
#' \deqn{\hat{U}_S = \frac{1}{n_1 n_0} \sum\limits_{i:Z_i=1} \sum\limits_{j:Z_j=0} I(S_i > S_j).}
#' Then, it calculates
#' \deqn{\hat{\delta} = \hat{U}_Y - \hat{U}_S.}
#' This function is generally not intended to be called directly by the user
#' and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
#'
#' @param MC_data A list containing:
#' \itemize{
#'   \item \code{P_observed}: A data frame or matrix with columns "Y" and "S".
#'   \item \code{Z}: Treatment assignment vector.
#'   \item \code{n1}: Number of treated units.
#'   \item \code{n0}: Number of control units.
#' }
#'
#' @return A list containing:
#' \itemize{
#'   \item \code{U_Y}: Mann-Whitney U statistic for the primary outcome Y computed on \code{P_observed}.
#'   \item \code{U_S}: Mann-Whitney U statistic for the surrogate S computed on \code{P_observed}.
#'   \item \code{delta}: The difference \code{U_Y} - \code{U_S}.
#' }
#' 
#' @references
#' \insertRef{parast2024rank}{BSET}
#' @importFrom stats wilcox.test
#' @export
compute_delta <- function(MC_data) {
  
  # Standardized Wilcoxon rank-sum statistics for Y
  U_Y <- stats::wilcox.test(
    x = MC_data$P_observed[MC_data$Z == 1, "Y"],
    y = MC_data$P_observed[MC_data$Z == 0, "Y"]
  )$statistic / (MC_data$n1 * MC_data$n0)
  
  # Standardized Wilcoxon rank-sum statistics for S
  U_S <- stats::wilcox.test(
    x = MC_data$P_observed[MC_data$Z == 1, "S"],
    y = MC_data$P_observed[MC_data$Z == 0, "S"]
  )$statistic / (MC_data$n1 * MC_data$n0)
  
  # Delta calculation
  delta <- U_Y - U_S
  
  # Output as a list
  output <- list(
    U_Y = as.numeric(U_Y),
    U_S = as.numeric(U_S),
    delta = as.numeric(delta)
  )
  
  return(output)
}

#######################
# FINAL USER FUNCTION #
#######################

#' Bayesian Surrogate Evaluation Test from Carlotti and Parast (2026)
#'
#' This function implements the Bayesian Surrogate Evaluation Test (BSET)
#' as proposed by \insertCite{carlotti2026bayesian;textual}{BSET}. When \code{X}
#' is \code{NULL} (the default), the model is fit without covariates; when \code{X}
#' is provided, a multivariate regression model is used to adjust for baseline
#' covariates. In both cases the function fits a Bayesian model using Stan to
#' generate posterior samples for the parameters of interest, which are then
#' used to conduct a Bayesian hypothesis test for evaluating the validity of
#' the surrogate marker. A frequentist test is also performed for comparison.
#'
#' \strong{Without covariates} (\code{X = NULL}), the Bayesian model is:
#' \deqn{(Y_i, S_i) = \begin{cases}
#' P_{1i}, & \text{if } Z_i = 1 \\
#' P_{0i}, & \text{if } Z_i = 0
#' \end{cases}, \quad i = 1, \ldots, n,}
#' \deqn{P_i \overset{\text{ind.}}{\sim} \mathcal{N}_4(\mu, \Sigma), \quad i = 1, \ldots, n,}
#' \deqn{\mu \sim \mathcal{N}_4(\mu_0, \Sigma_0),}
#' \deqn{\Sigma = \text{diag}(\sigma_{1:4}) \, \Omega \, \text{diag}(\sigma_{1:4}),}
#' \deqn{\sigma_k \sim \text{Half-Normal}(0, s_k), \quad k = 1, \ldots, 4,}
#' \deqn{\Omega \sim \text{LKJ}(\tau).}
#'
#' \strong{With covariates} (\code{X} provided), the Bayesian model is:
#' \deqn{P_i \overset{\text{ind.}}{\sim} \mathcal{N}_4(B X_i, \Sigma), \quad i = 1, \ldots, n,}
#' \deqn{B = \begin{bmatrix}
#' \beta_{1} & \beta_{2} & \beta_{3} & \beta_{4} \\
#' \end{bmatrix}^\top,}
#' \deqn{\beta_{k} \sim \mathcal{N}_d (\mu_{\beta}, \Sigma_{\beta}), \quad k = 1, \ldots, 4,}
#' with \eqn{\Sigma}, \eqn{\sigma_k}, and \eqn{\Omega} as above.
#'
#' This is a primary user-facing function of the package and includes working examples below.
#'
#' @param data A data frame containing the observed data.
#' @param Y Character. Name of the outcome variable.
#' @param S Character. Name of the surrogate variable.
#' @param Z Character. Name of the treatment assignment variable.
#' @param X Character vector. Names of the covariate columns to include in the model.
#'   When \code{NULL} (the default), the model is fit without covariates and the
#'   \code{mu_0} / \code{Sigma_0} prior parameters are used. When provided, the
#'   covariate-adjusted model is fit and the \code{intercept} / \code{mu_beta} /
#'   \code{Sigma_beta} prior parameters are used instead.
#' @param delta_true The true value of delta, used to calculate frequentist coverage during simulations (optional).
#' @param theta_true The true value of theta, used to calculate Bayesian coverage during simulations (optional).
#' @param seed Random seed for reproducibility (optional. If not provided, a random seed will be generated).
#' @param n_chains Number of MCMC chains to run (default is 4).
#' @param n_iter Number of iterations per MCMC chain (default is 2000).
#' @param burn_in_ratio Proportion of iterations to discard as burn-in (default is 0.25).
#' @param a,b Prior parameters for prior Beta distribution on V_S (default is a = 1, b = 1).
#' @param alpha Type I error rate for the test (default is 0.05).
#' @param beta Type II error rate for the test (default is 0.2).
#' @param V_S_zero Value of V_S under the null hypothesis (default is 0.5).
#' @param BF_alternative Alternative hypothesis for the Bayes factor test ("greater", "less" or "two.sided").
#' @param root_tolerance Numerical tolerance for root-finding algorithms (default is 1e-16).
#' @param mu_0 Prior mean vector for the mean parameters. Used only when \code{X = NULL}
#'   (default is a vector of zeros of length 4).
#' @param Sigma_0 Prior covariance matrix for the mean vector. Used only when \code{X = NULL}
#'   (default is a 4x4 identity matrix).
#' @param intercept Logical. Whether to include an intercept in the regression model.
#'   Used only when \code{X} is provided (default is \code{TRUE}).
#' @param mu_beta Prior mean vector for the regression coefficients. Used only when \code{X}
#'   is provided (default is a vector of zeros with length equal to the number of covariates,
#'   including the intercept if \code{intercept = TRUE}).
#' @param Sigma_beta Prior covariance matrix for the regression coefficients. Used only when
#'   \code{X} is provided (default is a diagonal matrix with variance 10, with dimensions equal
#'   to the number of covariates, including the intercept if \code{intercept = TRUE}).
#' @param s Prior scale parameters for the error variance (default is a vector of ones of length 4).
#' @param tau Prior parameter for the LKJ correlation distribution (default is 1).
#' @param plot Logical. Whether to plot the posterior distribution of theta (default is FALSE).
#' @param mute Logical. Whether to suppress Stan output during model fitting (default is TRUE).
#' @param parallel Logical. Whether to use parallel processing for MCMC sampling (default is TRUE).
#'
#' @return A list containing:
#' \itemize{
#'  \item \code{stan_cores}: The number of CPU cores used for MCMC sampling.
#'  \item \code{Bayesian_test}: A list containing the results of the Bayesian test, including posterior samples and credible intervals.
#'  \item \code{frequentist_test}: A list containing the results of the frequentist test, including point estimates and confidence intervals.
#'  \item \code{theta_posterior_plot}: A \code{ggplot} object showing the posterior distribution of \eqn{\theta}, with vertical lines indicating the credible interval, the \eqn{\eta} threshold, and the true values of \eqn{\delta} and \eqn{\theta} (if provided).
#'  }
#' @examples
#' # Generate data from the perfect surrogate setting of Parast et al. (2024)
#' set.seed(123)
#' data_no_X <- DGP_no_X(
#'   n = 100,
#'   p = 0.5,
#'   mu_star = c(6, 6, 2.5, 2.5),
#'   Sigma_star = kronecker(diag(2), matrix(c(3, 3, 3, 3.1), 2, 2)),
#'   model = "Gaussian"
#' )
#'
#' # Prepare the data frame
#' df_no_X <- data.frame(
#'   Y = data_no_X$P_observed[, "Y"],
#'   S = data_no_X$P_observed[, "S"],
#'   Z = data_no_X$Z
#' )
#'
#' # Run BSET without covariates (requires Stan compilation, ~3 minutes)
#' \donttest{
#' result_no_X <- BSET(
#'   data = df_no_X,
#'   Y = "Y",
#'   S = "S",
#'   Z = "Z",
#'   seed = 123,
#'   n_chains = 2,
#'   n_iter = 500
#' )
#' }
#'
#' # Generate data from the setting of Carlotti and Parast (2026) with a binary covariate
#' set.seed(123)
#' data_X <- DGP_X_binary(
#'   n = 100,
#'   p = 0.5,
#'   q = 0.5,
#'   mu_0 = c(5, 5, 0, 0),
#'   mu_1 = c(5, -5, 0, -10),
#'   Sigma_0 = kronecker(diag(2), matrix(c(1, 1, 1, 2), 2, 2)),
#'   Sigma_1 = kronecker(diag(2), matrix(c(1, 1, 1, 2), 2, 2))
#' )
#'
#' # Prepare the data frame
#' df_X <- data.frame(
#'   Y = data_X$P_observed[, "Y"],
#'   S = data_X$P_observed[, "S"],
#'   Z = data_X$Z,
#'   X = data_X$X
#' )
#'
#' # Run BSET with covariates (requires Stan compilation, ~3 minutes)
#' \donttest{
#' result_X <- BSET(
#'   data = df_X,
#'   Y = "Y",
#'   S = "S",
#'   Z = "Z",
#'   X = "X",
#'   seed = 123,
#'   n_chains = 2,
#'   n_iter = 500
#' )
#' }
#' @references
#' \insertRef{carlotti2026bayesian}{BSET}
#'
#' \insertRef{parast2024rank}{BSET}
#' @importFrom rlang .data
#' @export
BSET <- function(
    data, Y, S, Z, X = NULL, delta_true = NULL, theta_true = NULL,
    seed = NULL, n_chains = 4, n_iter = 2000, burn_in_ratio = 0.25,
    a = 1, b = 1, alpha = 0.05, beta = 0.2, V_S_zero = 0.5, BF_alternative = "greater", root_tolerance = 1e-16,
    mu_0 = rep(0, 4), Sigma_0 = diag(4),
    intercept = TRUE, mu_beta = NULL, Sigma_beta = NULL,
    s = rep(1, 4), tau = 1,
    plot = FALSE, mute = TRUE, parallel = TRUE
) {

  use_X <- !is.null(X)

  # Ensure all requested columns actually exist in the data
  required_cols <- c(Y, S, Z)
  if (use_X) required_cols <- c(required_cols, X)
  missing_cols <- setdiff(required_cols, names(data))

  if (length(missing_cols) > 0) {
    stop(paste("The following columns are missing from the data frame:", paste(missing_cols, collapse = ", ")))
  }

  # Extract variables from the data frame
  Y <- data[[Y]]
  S <- data[[S]]
  Z <- data[[Z]]

  # Check for NAs
  if (anyNA(data[, required_cols])) {
    warning("Data contains missing values. Filter them first.")
  }

  # Sample size
  n <- nrow(data)

  # Covariate-specific processing
  if (use_X) {
    X <- as.matrix(data[X])
    d <- ncol(X)
    if (intercept) {
      X <- cbind(1, X)
      d <- d + 1
    }
    if (is.null(mu_beta))    mu_beta    <- rep(0, d)
    if (is.null(Sigma_beta)) Sigma_beta <- 10 * diag(d)
  }

  # Burn-in iterations
  burn_in <- floor(n_iter * burn_in_ratio)

  # Total number of posterior samples
  n_samples <- n_chains * (n_iter - burn_in)

  # Compute V_S_star
  V_S_star <- compute_V_S_star(
    n = n,
    alpha = alpha,
    beta = beta,
    V_S_zero = V_S_zero,
    a = a,
    b = b,
    BF_alternative = BF_alternative,
    root_tolerance = root_tolerance
  )$V_S_star

  # Parallel vs sequential execution
  if (parallel) {
    # Detect available cores (cap at 2 during CRAN checks)
    available_cores <- if (isTRUE(as.logical(Sys.getenv("_R_CHECK_LIMIT_CORES_", "FALSE")))) {
      2L
    } else {
      parallel::detectCores() - 1
    }

    # Maximum allowed PSOCK connections. R default is 128
    max_connections <- getOption("future.connections.max", 128) - 4

    # Number of cores to use
    stan_cores <- min(available_cores, max_connections, n_chains)

    # Plan parallel execution
    future::plan(future::multisession, workers = stan_cores)

    # Shut down workers on exit
    on.exit(future::plan(future::sequential), add = TRUE)
  } else {
    stan_cores <- 1
  }

  # Ensure compiled models are saved and reused
  rstan::rstan_options(auto_write = TRUE)

  # Set the seed for reproducibility
  stan_seed <- if (!is.null(seed)) seed else sample.int(.Machine$integer.max, 1)

  # Select Stan model and data based on whether covariates are provided
  if (use_X) {
    stan_file <- system.file("stan", "BSET_X.stan", package = "BSET")
    stan_data <- list(
      n = n,
      d = d,
      P_observed = cbind(Y, S),
      Z = Z,
      X = X,
      mu_beta = mu_beta,
      Sigma_beta = Sigma_beta,
      s = s,
      tau = tau
    )
  } else {
    stan_file <- system.file("stan", "BSET_no_X.stan", package = "BSET")
    stan_data <- list(
      n = n,
      P_observed = cbind(Y, S),
      Z = Z,
      mu_0 = mu_0,
      Sigma_0 = Sigma_0,
      s = s,
      tau = tau
    )
  }

  # Compile the model if it doesn't exist, otherwise load the pre-compiled model
  stan_model <- rstan::stan_model(file = stan_file)

  # Fit Stan model
  if (mute) {
    stan_fit <- suppressMessages(
      suppressWarnings(
        rstan::sampling(
          object = stan_model,
          data = stan_data,
          chains = n_chains,
          cores = stan_cores,
          iter = n_iter,
          warmup = burn_in,
          seed = stan_seed,
          control = list(adapt_delta = 0.999, max_treedepth = 15),
          refresh = 0
        )
      )
    )
  } else {
    stan_fit <- rstan::sampling(
      object = stan_model,
      data = stan_data,
      chains = n_chains,
      cores = stan_cores,
      iter = n_iter,
      warmup = burn_in,
      seed = stan_seed,
      control = list(adapt_delta = 0.999, max_treedepth = 15),
      refresh = 0
    )
  }

  # Extract posterior samples
  HMC_samples <- rstan::extract(stan_fit)

  # Reorder posterior draws: [n_subjects, variables, n_samples]
  P_HMC <- aperm(HMC_samples$P, c(2, 3, 1))

  # Bayesian test
  Bayesian_test_results <- Bayesian_test(
    P_MCMC = P_HMC,
    alpha = alpha,
    V_S_star = V_S_star,
    theta_true = if (!is.null(theta_true)) theta_true else NULL
  )

  # Frequentist test
  frequentist_test_results <- frequentist_test(
    P_observed = cbind(Y, S),
    Z = Z,
    alpha = alpha,
    beta = beta,
    delta_true = if (!is.null(delta_true)) delta_true else NULL
  )

  # Posterior plot for theta
  if (plot) {
    all_colors <- c(
      "Bayesian CI (upper bound)"      = "#0072B2",
      "Bayesian threshold (\u03b7)"    = "#56B4E9",
      "True \u03b8"                    = "#551A8B",
      "Frequentist CI (upper bound)"   = "#D55E00",
      "Frequentist threshold (\u03b5)" = "#E69F00",
      "True \u03b4"                    = "#CC79A7"
    )

    all_linetypes <- c(
      "Bayesian CI (upper bound)"      = "33",
      "Bayesian threshold (\u03b7)"    = "33",
      "True \u03b8"                    = "solid",
      "Frequentist CI (upper bound)"   = "33",
      "Frequentist threshold (\u03b5)" = "33",
      "True \u03b4"                    = "solid"
    )

    lvls <- character(0)
    if (!is.null(theta_true)) lvls <- c(lvls, "True \u03b8")
    lvls <- c(lvls, "Bayesian CI (upper bound)", "Bayesian threshold (\u03b7)")
    if (!is.null(delta_true)) lvls <- c(lvls, "True \u03b4")
    lvls <- c(lvls, "Frequentist CI (upper bound)", "Frequentist threshold (\u03b5)")

    dashed_df <- data.frame(
      xintercept = c(
        Bayesian_test_results$CI[2],
        Bayesian_test_results$threshold,
        frequentist_test_results$CI[2],
        frequentist_test_results$threshold
      ),
      label = factor(
        c("Bayesian CI (upper bound)", "Bayesian threshold (\u03b7)",
          "Frequentist CI (upper bound)", "Frequentist threshold (\u03b5)"),
        levels = lvls
      )
    )

    theta_posterior_plot <- ggplot2::ggplot(
      data.frame(theta = Bayesian_test_results$theta_MCMC),
      mapping = ggplot2::aes(x = .data$theta)
    ) +
      ggplot2::geom_histogram(
        binwidth = 0.02, fill = "lightgray", color = "black", alpha = 0.8
      ) +
      ggplot2::geom_vline(
        data = dashed_df,
        ggplot2::aes(xintercept = xintercept, color = label, linetype = label),
        linewidth = 1, key_glyph = "path"
      )

    if (!is.null(theta_true) || !is.null(delta_true)) {
      solid_xint   <- c()
      solid_labels <- c()
      if (!is.null(theta_true)) {
        solid_xint   <- c(solid_xint, theta_true)
        solid_labels <- c(solid_labels, "True \u03b8")
      }
      if (!is.null(delta_true)) {
        solid_xint   <- c(solid_xint, delta_true)
        solid_labels <- c(solid_labels, "True \u03b4")
      }
      solid_df <- data.frame(
        xintercept = solid_xint,
        label      = factor(solid_labels, levels = lvls)
      )
      theta_posterior_plot <- theta_posterior_plot +
        ggplot2::geom_vline(
          data = solid_df,
          ggplot2::aes(xintercept = xintercept, color = label, linetype = label),
          linewidth = 1, key_glyph = "path"
        )
    }

    theta_posterior_plot <- theta_posterior_plot +
      ggplot2::scale_color_manual(
        values = all_colors[lvls], breaks = lvls, drop = TRUE, name = NULL
      ) +
      ggplot2::scale_linetype_manual(
        values = all_linetypes[lvls], breaks = lvls, drop = TRUE, name = NULL
      ) +
      ggplot2::coord_cartesian(xlim = c(-1, 1)) +
      ggplot2::theme_minimal() +
      ggplot2::theme(
        legend.position  = "right",
        legend.key.width = grid::unit(0.8, "cm")
      ) +
      ggplot2::labs(x = expression(theta), y = "Frequency")
  }

  # Output
  output <- list(
    stan_cores = stan_cores,
    Bayesian_test = Bayesian_test_results,
    frequentist_test = frequentist_test_results,
    theta_posterior_plot = if (plot) theta_posterior_plot else NULL
  )

  return(output)
}

#' Data Generating Process without Baseline Covariates
#'
#' This function generates potential outcomes from the simulation settings
#' described in \insertCite{parast2024rank;textual}{BSET}. It creates a dataset of potential outcomes
#' \deqn{P = (Y_1, S_1, Y_0, S_0)} and observed outcomes 
#' \deqn{P_{observed} = (Y, S)} based on a random treatment assignment \eqn{Z}.
#' 
#' @details The function supports two types of data-generating processes:
#' \itemize{
#'   \item \strong{Gaussian model:} Potential outcomes are drawn from a 
#'   multivariate normal distribution:
#'   \deqn{P \sim \mathcal{N}_{4}(\mu^{*}, \Sigma^{*}).}
#'   \item \strong{Non-linear model:} Potential outcomes for the surrogate are generated from a non-Gaussian
#'   distribution, and the potential outcomes for the primary outcome are generated from a non-linear function of the surrogate plus non-Gaussian noise.
#' }
#'
#' @param n Integer. Total sample size.
#' @param p Numeric. Probability of being assigned to the treatment group (Z=1).
#' @param mu_star Numeric vector. The mean vector for \eqn{P}. Required if \code{model = "Gaussian"}.
#' @param Sigma_star Matrix. The covariance matrix for \eqn{P}. Required if \code{model = "Gaussian"}.
#' @param model Character. The type of data generation: \code{"Gaussian"} 
#'   or \code{"misspecified"}.
#'
#' @return A list containing:
#' \itemize{
#'   \item \code{Z}: Treatment assignment vector.
#'   \item \code{n1}: Number of treated units.
#'   \item \code{n0}: Number of control units.
#'   \item \code{P}: Full matrix of potential outcomes.
#'   \item \code{P_observed}: Observed outcomes \eqn{(Y, S)} corresponding to the assigned treatment \eqn{Z}.
#'   \item \code{P_unobserved}: Counterfactual outcomes under the opposite treatment.
#' }
#' This function is useful for generating synthetic data to test or explore
#' the method, for instance to verify the behavior of \code{BSET_no_X} under
#' known simulation settings.
#'
#' @examples
#' set.seed(123)
#' data <- DGP_no_X(
#'   n = 100,
#'   p = 0.5,
#'   mu_star = c(6, 6, 2.5, 2.5),
#'   Sigma_star = kronecker(diag(2), matrix(c(3, 3, 3, 3.1), 2, 2)),
#'   model = "Gaussian"
#' )
#' @references
#' \insertRef{parast2024rank}{BSET}
#' @importFrom Rdpack reprompt
#' @importFrom mvtnorm rmvnorm
#' @importFrom stats rbinom rnorm
#' @export
DGP_no_X <- function(n, p, mu_star = NULL, Sigma_star = NULL, model = c("Gaussian", "misspecified")) {
  
  model <- match.arg(model)
  
  # Treatment assignment
  Z <- stats::rbinom(n = n, size = 1, prob = p)
  n1 <- sum(Z)
  n0 <- n - n1
  
  # Potential outcomes
  if (model == "Gaussian") {
    if (is.null(mu_star) || is.null(Sigma_star)) {
      stop("For Gaussian DGP, mu_star and Sigma_star must be provided.")
    }
    P <- mvtnorm::rmvnorm(n = n, mean = mu_star, sigma = Sigma_star)
    colnames(P) <- c("Y1", "S1", "Y0", "S0")
  } else if (model == "misspecified") {
    P <- matrix(data = NA, nrow = n, ncol = 4)
    colnames(P) <- c("Y1", "S1", "Y0", "S0")
    for (i in 1:n) {
      P[i, "S1"] <- exp(stats::rnorm(1, 2.5, 1.5))
      P[i, "S0"] <- exp(stats::rnorm(1, 0.5, 1.5))
      P[i, "Y1"] <- 2.0 + 1.2*sqrt(P[i, "S1"]) + 0.3*exp(P[i, "S1"]/500) + exp(stats::rnorm(1, 0, sqrt(0.3)))
      P[i, "Y0"] <- 0.8*sqrt(P[i, "S0"]) + 0.2*exp(P[i, "S0"]/50) + exp(stats::rnorm(1, 0, sqrt(0.3)))
    }
  }
  
  # Observed and unobserved outcomes (Vectorized for speed)
  P_observed <- matrix(NA, nrow = n, ncol = 2, dimnames = list(NULL, c("Y", "S")))
  P_unobserved <- matrix(NA, nrow = n, ncol = 2, dimnames = list(NULL, c("Y", "S")))
  
  # If Z=1, observed is (Y1, S1) [cols 1:2], unobserved is (Y0, S0) [cols 3:4]
  P_observed[Z == 1, ]   <- P[Z == 1, 1:2]
  P_unobserved[Z == 1, ] <- P[Z == 1, 3:4]
  
  # If Z=0, observed is (Y0, S0) [cols 3:4], unobserved is (Y1, S1) [cols 1:2]
  P_observed[Z == 0, ]   <- P[Z == 0, 3:4]
  P_unobserved[Z == 0, ] <- P[Z == 0, 1:2]
  
  return(list(
    Z = Z,
    n1 = n1,
    n0 = n0,
    P = P,
    P_observed = P_observed,
    P_unobserved = P_unobserved
  ))
}

#' Compute \eqn{v_S} from Carlotti and Parast (2026)
#'
#' This function determines the value \eqn{v_S} that is used to compute the
#' surrogate validation threshold \eqn{\eta} from \insertCite{carlotti2026bayesian;textual}{BSET}:
#' \deqn{\eta = \max \{v_Y - v_S, 0\},}
#' where \eqn{v_Y} is the hypothesized value of the treatment effect on the
#' primary outcome (typically set equal to the estimate computed on the
#' available data) and \eqn{v_S} is the value that satisfies the following power
#' constraint:
#' \deqn{P(\text{BF}_n \geq \text{BF}_{n, \alpha} \; | \; V_S = v_S) = 1 - \beta,}
#' where \eqn{\text{BF}_{n, \alpha}} is the \eqn{(1 - \alpha)} quantile of the
#' Bayes factor distribution under the null hypothesis \eqn{V_S = V^0_{S}}, and \eqn{1 - \beta} is the desired power of the
#' test. The function computes the distribution of the Bayes factor under the null
#' hypothesis, derives the critical value \eqn{\text{BF}_{n, \alpha}}, and then
#' uses a root-finding algorithm to solve for the value of \eqn{v_S} that
#' satisfies the power constraint.
#' This function is generally not intended to be called directly by the user
#' and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
#'
#' @param n Integer. Sample size.
#' @param alpha Numeric. Type I error rate (default is 0.05).
#' @param beta Numeric. Type II error rate (default is 0.2).
#' @param V_S_zero Numeric. The hypothesized value of the surrogate's treatment effect under the null hypothesis (default is 0.5).
#' @param a Numeric. First shape parameter alpha for the Beta prior (default is 1).
#' @param b Numeric. Second shape parameter beta for the Beta prior (default is 1).
#' @param BF_alternative Character. The type of alternative hypothesis: either \code{"two_sided"} or \code{"greater"}.
#' @param root_tolerance Numeric. Tolerance level for the root-finding algorithm (default is 1e-16).
#'
#' @return A list containing:
#' \itemize{
#'   \item \code{BF_alpha}: The critical value of the Bayes factor corresponding to the specified alpha level.
#'   \item \code{V_S_star}: The value of \eqn{v_S} that satisfies the power constraint for the surrogate validation test.
#' }
#' 
#' @references
#' \insertRef{carlotti2026bayesian}{BSET}
#' @importFrom stats uniroot
#' @importFrom dplyr %>% filter slice pull
#' @importFrom rlang .data
#' @export
compute_V_S_star <- function(n, alpha = 0.05, beta = 0.2, V_S_zero = 0.5, 
                             a = 1, b = 1, BF_alternative = "greater", root_tolerance = 1e-16) {
  
  # Find BF_alpha using the distribution function we formatted earlier
  BF_alpha <- compute_BF_distribution(
    n = n,
    V_S_true = V_S_zero,
    V_S_zero = V_S_zero,
    a = a,
    b = b,
    BF_alternative = BF_alternative
  ) %>%
    dplyr::filter(.data$BF_CDF >= 1 - alpha) %>%
    dplyr::slice(1) %>%
    dplyr::pull(.data$BF_values)
  
  # Objective function for uniroot
  objective_function <- function(V) {
    BF_dist <- compute_BF_distribution(
      n = n,
      V_S_true = V,
      V_S_zero = V_S_zero,
      a = a,
      b = b,
      BF_alternative = BF_alternative
    )
    
    # Output: difference between current power and target power
    output <- beta - BF_dist$BF_CDF[BF_dist$BF_values == BF_alpha]
    return(output)
  }
  
  # Define search interval based on logic
  if (BF_alternative == "two_sided") {
    interval <- c(0.5, 1) 
  } else if (BF_alternative == "greater") {
    interval <- if (V_S_zero < 0.5) c(0.5, 1) else c(V_S_zero, 1)
  }
    
  # Solve for V_S_star
  sol <- stats::uniroot(
    f = objective_function,
    interval = interval,
    tol = root_tolerance
  )
  
  # Output requested alternative
  output <- list(
    BF_alpha = BF_alpha,
    V_S_star = sol$root
  )
  
  return(output)
}

#' Frequentist Test from Parast et al. (2024)
#'
#' This function performs a frequentist test for surrogate evaluation based on 
#' the rank-based methodology of \insertCite{parast2024rank;textual}{BSET}. It calculates confidence
#' intervals, the \eqn{\varepsilon} threshold used, and determines if the surrogate is
#' valid.
#' This function is generally not intended to be called directly by the user
#' and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
#'
#' @param P_observed Observed outcomes \eqn{(Y, S)} corresponding to the assigned treatment \eqn{Z}.
#' @param Z Treatment assignment vector.
#' @param alpha Numeric. Significance level for the confidence interval (default is 0.05).
#' @param beta Numeric. Type II error rate (default is 0.2).
#' @param delta_true Numeric (optional). The true value of \eqn{\delta}, used to calculate 
#'   frequentist coverage during simulations.
#'
#' @return A list containing:
#' \itemize{
#'   \item \code{CI}: The calculated confidence interval for \eqn{\delta}.
#'   \item \code{threshold}: The \eqn{\varepsilon} threshold value used in the test.
#'   \item \code{coverage}: Logical indicating if \code{delta_true} falls within the \code{CI}
#'     (if \code{delta_true} is provided).
#'   \item \code{power}: Logical indicating if the upper bound of \code{CI} is below \code{threshold}, which indicates that the test identifies the surrogate as valid.
#' }
#' 
#' @references
#' \insertRef{parast2024rank}{BSET}
#' @importFrom SurrogateRank test.surrogate
#' @export
frequentist_test <- function(P_observed, Z, alpha = 0.05, beta = 0.2, delta_true = NULL) {
  
  # Surrogacy test from Parast et al. (2024)
  Parast_test <- SurrogateRank::test.surrogate(
    yone = P_observed[Z == 1, "Y"],
    yzero = P_observed[Z == 0, "Y"],
    sone = P_observed[Z == 1, "S"],
    szero = P_observed[Z == 0, "S"],
    power.want.s = 1 - beta
  )
  
  # Calculations for coverage
  if (!is.null(delta_true)) {
    # Check if true delta is below the upper bound of the CI
    frequentist_coverage <- delta_true < Parast_test$ci.delta[2]
  } else {
    frequentist_coverage <- NA
  }
  
  # Return as a list
  list(
    delta = Parast_test$delta.estimate, 
    CI = Parast_test$ci.delta,
    threshold = Parast_test$epsilon.used,
    coverage = frequentist_coverage,
    power = Parast_test$is.surrogate
  )
}

#' Monte Carlo Computation of the Parameter \eqn{\theta} from Carlotti and Parast (2026)
#'
#' This function implements a Monte Carlo approach to estimate the parameter
#' \eqn{\theta} from \insertCite{carlotti2026bayesian;textual}{BSET}. This parameter represents the
#' difference in treatment effects between the primary and surrogate outcomes,
#' both measured using the probability that the treated outcome is larger
#' than the control outcome.
#' 
#' @details The function processes data from a chosen data generating process,
#' computing the sample probabilities for both the primary outcome \eqn{Y} and
#' the surrogate \eqn{S}:
#' \deqn{\hat{V}_Y = \frac{1}{n} \sum\limits^{n}_{i=1} I(Y_{1i} > Y_{0i}),}
#' \deqn{\hat{V}_S = \frac{1}{n} \sum\limits^{n}_{i=1} I(S_{1i} > S_{0i}).}
#' Then, it calculates
#' \deqn{\hat{\theta} = \hat{V}_Y - \hat{V}_S.}
#' This function is generally not intended to be called directly by the user
#' and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
#'
#' @param MC_data A list containing:
#' \itemize{
#'   \item \code{P}: A matrix or data frame of potential outcomes with columns 
#'     "Y1", "Y0", "S1", and "S0".
#' }
#'
#' @return A list containing the true values:
#' \itemize{
#'   \item \code{V_Y}: The Monte Carlo estimate of \eqn{P(Y_{1i} > Y_{0i})} computed on \code{P}.
#'   \item \code{V_S}: The Monte Carlo estimate of \eqn{P(S_{1i} > S_{0i})} computed on \code{P}.
#'   \item \code{theta}: The difference \code{V_Y} - \code{V_S}.
#' }
#' 
#' @references
#' \insertRef{carlotti2026bayesian}{BSET}
#' @export
compute_theta <- function(MC_data) {
  
  # Calculate true probabilities from potential outcomes
  # V_Y = P(Y1 > Y0)
  V_Y <- mean(MC_data$P[, "Y1"] > MC_data$P[, "Y0"])
  
  # V_S = P(S1 > S0)
  V_S <- mean(MC_data$P[, "S1"] > MC_data$P[, "S0"])
  
  # Theta (True discrepancy)
  theta <- V_Y - V_S
  
  # Output
  output <- list(
    V_Y = V_Y,
    V_S = V_S,
    theta = theta
  )
  
  return(output)
}

#' Data Generating Process with a Binary Covariate
#'
#' This function generates potential outcomes from a data generating process
#' similar to the one described in \insertCite{parast2024rank;textual}{BSET}, but with the addition
#' of a binary covariate X. It creates a dataset of potential outcomes
#' \deqn{P = (Y_1, S_1, Y_0, S_0)} and observed outcomes
#' \deqn{P_{observed} = (Y, S)} based on a random treatment assignment \eqn{Z}.
#' 
#' @details The potential outcomes are generated from multivariate normal
#' distributions with different mean vectors and covariance matrices depending
#' on the value of \eqn{X}. Specifically:
#' \deqn{P \mid X = 0 \sim \mathcal{N}_{4}(\mu^{0}, \Sigma^{0}), \\
#' P \mid X = 1 \sim \mathcal{N}_{4}(\mu^{1}, \Sigma^{1}).}
#'
#' @param n Integer. Total sample size.
#' @param p Numeric. Probability of being assigned to the treatment group \eqn{(Z=1)}.
#' @param q Numeric. Probability of the binary covariate X being 1.
#' @param mu_0 Numeric vector. Mean vector for \eqn{P} when \eqn{X=0}.
#' @param mu_1 Numeric vector. Mean vector for \eqn{P} when \eqn{X=1}.
#' @param Sigma_0 Matrix. Covariance matrix for \eqn{P} when \eqn{X=0}.
#' @param Sigma_1 Matrix. Covariance matrix for \eqn{P} when \eqn{X=1}.
#'
#' @return A list containing:
#' \itemize{
#'   \item \code{X}: The binary covariate vector.
#'   \item \code{n_X1}: Number of units with \eqn{X=1}.
#'   \item \code{n_X0}: Number of units with \eqn{X=0}.
#'   \item \code{Z}: Treatment assignment vector.
#'   \item \code{n1}: Number of treated units.
#'   \item \code{n0}: Number of control units.
#'   \item \code{P}: Full matrix of potential outcomes.
#'   \item \code{P_observed}: Observed outcomes \eqn{(Y, S)} corresponding to the assigned treatment \eqn{Z}.
#'   \item \code{P_unobserved}: Counterfactual outcomes under the opposite treatment.
#' }
#' This function is useful for generating synthetic data to test or explore
#' the method, for instance to verify the behavior of \code{BSET_X} under
#' known simulation settings.
#'
#' @examples
#' set.seed(123)
#' data <- DGP_X_binary(
#'   n = 100,
#'   p = 0.5,
#'   q = 0.5,
#'   mu_0 = c(5, 5, 0, 0),
#'   mu_1 = c(5, -5, 0, -10),
#'   Sigma_0 = kronecker(diag(2), matrix(c(1, 1, 1, 2), 2, 2)),
#'   Sigma_1 = kronecker(diag(2), matrix(c(1, 1, 1, 2), 2, 2))
#' )
#' @references
#' \insertRef{carlotti2026bayesian}{BSET}
#' @importFrom mvtnorm rmvnorm
#' @importFrom stats rbinom
#' @export
DGP_X_binary <- function(n, p, q, mu_0, mu_1, Sigma_0, Sigma_1) {
  
  # Binary covariate
  X <- stats::rbinom(n = n, size = 1, prob = q)
  n_X1 <- sum(X)
  n_X0 <- n - n_X1
  
  # Potential outcomes generation
  P_X0 <- mvtnorm::rmvnorm(n = n, mean = mu_0, sigma = Sigma_0)
  P_X1 <- mvtnorm::rmvnorm(n = n, mean = mu_1, sigma = Sigma_1)
  
  colnames(P_X0) <- colnames(P_X1) <- c("Y1", "S1", "Y0", "S0")
  
  # Composite potential outcomes matrix
  P <- X * P_X1 + (1 - X) * P_X0
  
  # Treatment assignment
  Z <- stats::rbinom(n = n, size = 1, prob = p)
  n1 <- sum(Z)
  n0 <- n - n1
  
  # Observed and Unobserved
  # When Z=1, we observe cols 1-2 (Y1, S1). When Z=0, we observe cols 3-4 (Y0, S0).
  P_observed <- Z * P[, c("Y1", "S1")] + (1 - Z) * P[, c("Y0", "S0")]
  P_unobserved <- Z * P[, c("Y0", "S0")] + (1 - Z) * P[, c("Y1", "S1")]
  
  colnames(P_observed) <- colnames(P_unobserved) <- c("Y", "S")
  
  return(list(
    X = X,
    n_X1 = n_X1,
    n_X0 = n_X0,
    Z = Z,
    n1 = n1,
    n0 = n0,
    P = P,
    P_observed = P_observed,
    P_unobserved = P_unobserved
  ))
}

#' Data Generating Process with a Gaussian Covariate
#' 
#' This function generates potential outcomes from a data generating process
#' similar to the one described in \insertCite{parast2024rank;textual}{BSET}, but with the addition
#' of a Gaussian covariate X. It creates a dataset of potential outcomes
#' \deqn{P = (Y_1, S_1, Y_0, S_0)} and observed outcomes
#' \deqn{P_{observed} = (Y, S)} based on a random treatment assignment \eqn{Z}.
#' 
#' @details The potential outcomes are generated from a multivariate normal
#' distribution with mean vector and covariance matrix that depend on the
#' value of \eqn{X}. Specifically, the mean vector is a linear function of \eqn{X}:
#' \deqn{\mu(X) = x \cdot (\beta_{Y1}, \beta_{S1}, \beta_{Y0}, \beta_{S0})^T,}
#' and the covariance matrix is constant across values of \eqn{X}:
#' \deqn{\Sigma(X) = \Sigma.}
#' 
#' @param n Integer. Total sample size.
#' @param p Numeric. Probability of being assigned to the treatment group \eqn{(Z=1)}.
#' @param beta Numeric vector. Coefficients for the linear function of the covariate \eqn{X}.
#' @param Sigma Matrix. Covariance matrix for the potential outcomes.
#' @param m Numeric. Mean of the Gaussian covariate \eqn{X}.
#' @param s Numeric. Standard deviation of the Gaussian covariate \eqn{X}.
#' 
#' @return A list containing:
#' \itemize{
#'  \item \code{X}: The Gaussian covariate vector.
#'  \item \code{Z}: Treatment assignment vector.
#'  \item \code{n1}: Number of treated units.
#'  \item \code{n0}: Number of control units.
#'  \item \code{P}: Full matrix of potential outcomes.
#'  \item \code{P_observed}: Observed outcomes \eqn{(Y, S)} corresponding to the assigned treatment \eqn{Z}.
#'  \item \code{P_unobserved}: Counterfactual outcomes under the opposite treatment.
#' }
#' This function is useful for generating synthetic data to test or explore
#' the method, for instance to verify the behavior of \code{BSET_X} under
#' known simulation settings.
#'
#' @examples
#' set.seed(123)
#' data <- DGP_X_Gaussian(
#'   n = 100,
#'   p = 0.5,
#'   beta = c(1, 7, 0, 6),
#'   Sigma = 0.5 * diag(4),
#'   m = 3,
#'   s = 1
#' )
#' @references
#' \insertRef{carlotti2026bayesian}{BSET}
#' @importFrom mvtnorm rmvnorm
#' @importFrom stats rbinom rnorm
#' @export
DGP_X_Gaussian <- function(n, p, beta, Sigma, m, s) {
  
  # Continuous covariate
  X <- stats::rnorm(n = n, mean = m, sd = s)
  
  # Potential outcomes generation
  mu_X <- X %*% t(beta)
  P <- matrix(data = NA, nrow = n, ncol = 4)
  colnames(P) <- c("Y1", "S1", "Y0", "S0")
  
  for (i in 1:n) {
    P[i, ] <- mvtnorm::rmvnorm(n = 1, mean = mu_X[i, ], sigma = Sigma)
  }
  
  # Treatment assignment
  Z <- stats::rbinom(n = n, size = 1, prob = p)
  n1 <- sum(Z)
  n0 <- n - n1
  
  # Observed and Unobserved (Vectorized logic)
  P_observed <- Z * P[, c("Y1", "S1")] + (1 - Z) * P[, c("Y0", "S0")]
  P_unobserved <- Z * P[, c("Y0", "S0")] + (1 - Z) * P[, c("Y1", "S1")]
  
  colnames(P_observed) <- colnames(P_unobserved) <- c("Y", "S")
  
  return(list(
    X = X,
    Z = Z,
    n1 = n1,
    n0 = n0,
    P = P,
    P_observed = P_observed,
    P_unobserved = P_unobserved
  ))
}

#' Monte Carlo Computation of the Estimands for the Simulation Study in Carlotti and Parast (2026)
#'
#' This function iterates through the simulation settings defined in Carlotti
#' and Parast (2026) and estimates the true values of \eqn{U_Y}, \eqn{U_S},
#' \eqn{\delta}, \eqn{V_Y}, \eqn{V_S}, and \eqn{\theta} using a Monte Carlo
#' dataset generated according to the specified data-generating processes.
#' 
#' @details
#' The settings are defined as follows:
#' \itemize{
#'   \item Setting 1: \strong{X binary}
#'   \itemize{
#'     \item If \eqn{X = 1}:
#'     \deqn{Y_1 \sim \mathcal{N}(5, 1), \quad Y_0 \sim \mathcal{N}(0, 1)}
#'     \deqn{S_1 = Y_1 + \mathcal{N}(0, 1), \quad S_0 = Y_0 + \mathcal{N}(0, 1)}
#'     \item If \eqn{X = 0}:
#'     \deqn{Y_1 \sim \mathcal{N}(5, 1), \quad Y_0 \sim \mathcal{N}(0, 1)}
#'     \deqn{S_1 = Y_1 + \mathcal{N}(-10, 1), \quad S_0 = Y_0 + \mathcal{N}(-10, 1)}
#'   }
#'   \item Setting 2: \strong{X Gaussian}
#'   \deqn{(Y_1, S_1, Y_0, S_0) \mid X = x \sim \mathcal{N}(x (1, 7, 0, 6)', \frac{1}{2} I_4),}
#' }
#' This function is generally not intended to be called directly by the user.
#' It is provided as a utility for computing the true parameter values for the
#' simulation settings described in \insertCite{carlotti2026bayesian;textual}{BSET}.
#'
#' @param MC_samples Integer. The number of Monte Carlo samples to generate per setting.
#'
#' @return A data frame containing the Monte Carlo estimates for each setting:
#' \itemize{
#'   \item \code{setting}: The index of the simulation setting.
#'   \item \code{U_Y_MC}, \code{U_S_MC}, \code{delta_MC}: Parameters of interest from \insertCite{parast2024rank;textual}{BSET}.
#'   \item \code{V_Y_MC}, \code{V_S_MC}, \code{theta_MC}: Parameters of interest from \insertCite{carlotti2026bayesian;textual}{BSET}.
#' }
#' 
#' @references
#' \insertRef{carlotti2026bayesian}{BSET}
#' @export
compute_estimands_Carlotti_and_Parast_2026 <- function(MC_samples) {
  # Treatment assignment probability
  p = 0.5
  
  # Possible settings
  n_settings <- 2
  settings <- vector("list", n_settings)
  
  for (setting in 1:n_settings) {
    
    # Choice of the setting
    if (setting == 1) {
      ############
      # X binary #
      ############
      
      # Setting name
      setting_name <- "X_binary"
      
      # Setting label
      setting_label <- "X binary"
      
      # Binary covariate probability
      q <- 0.5
      
      # Number of covariates (including the intercept)
      d <- 2
      
      # Probability of X = 1
      q <- 0.5
      
      # Mean vector for potential outcomes when X = 0
      mu_0 <- c(5, 5, 0, 0)
      
      # Mean vector for potential outcomes when X = 1
      mu_1 <- c(5, -5, 0, -10)
      
      # Covariance matrix for potential outcomes when X = 0
      Sigma_0 <- kronecker(diag(2), matrix(
        data = c(1, 1,
                 1, 2),
        nrow = 2,
        ncol = 2))
      
      # Covariance matrix for potential outcomes when X = 1
      Sigma_1 <- kronecker(diag(2), matrix(
        data = c(1, 1,
                 1, 2),
        nrow = 2,
        ncol = 2))
      
      # Store setting parameters in the list
      settings[[setting]] <- list(
        setting_name = setting_name,
        setting_label = setting_label,
        q = q,
        d = d,
        mu_0 = mu_0,
        mu_1 = mu_1,
        Sigma_0 = Sigma_0,
        Sigma_1 = Sigma_1
      )
    } else if (setting == 2) {
      ##############
      # X Gaussian #
      ##############
      
      # Setting name
      setting_name <- "X_gaussian"
      
      # Setting label
      setting_label <- "X Gaussian"
      
      # Number of covariates (including the intercept)
      d <- 2
      
      # Vector of coefficients for the covariates in the potential outcomes model
      beta <- c(1, 7, 0, 6)
      
      # Covariance matrix of the potential outcomes
      Sigma <- 0.5 * diag(4)
      
      # Mean vector the Gaussian covariate X
      m <- 3
      
      # Standard deviation of the Gaussian covariate X
      s <- 1
      
      # Store setting parameters in the list
      settings[[setting]] <- list(
        setting_name = setting_name,
        setting_label = setting_label,
        d = d,
        beta = beta,
        Sigma = Sigma,
        m = m,
        s = s
      )
    }
  }
  
  # Initialize estimands dataframe
  estimands <- data.frame(
    setting = 1:length(settings),
    U_Y_MC = as.numeric(NA),
    U_S_MC = as.numeric(NA),
    delta_MC = as.numeric(NA),
    V_Y_MC = as.numeric(NA),
    V_S_MC = as.numeric(NA),
    theta_MC = as.numeric(NA)
  )
  
  # Loop over settings
  for (i in 1:n_settings) {
    # Extract setting parameters
    setting_name <- settings[[i]]$setting_name
    setting_label <- settings[[i]]$setting_label
    d <- settings[[i]]$d
    
    if (setting_name == "X_binary") {
      # Binary covariate parameters
      q <- settings[[i]]$q
      mu_0 <- settings[[i]]$mu_0
      mu_1 <- settings[[i]]$mu_1
      Sigma_0 <- settings[[i]]$Sigma_0
      Sigma_1 <- settings[[i]]$Sigma_1
      
      # Generate large-scale Monte Carlo data
      MC_data <- DGP_X_binary(
        n = MC_samples,
        p = p,
        q = q,
        mu_0 = mu_0,
        mu_1 = mu_1,
        Sigma_0 = Sigma_0,
        Sigma_1 = Sigma_1
      )
    } else if (setting_name == "X_gaussian") {
      # Gaussian covariate parameters
      beta <- settings[[i]]$beta
      Sigma <- settings[[i]]$Sigma
      m <- settings[[i]]$m
      s <- settings[[i]]$s
      
      # Generate large-scale Monte Carlo data
      MC_data <- DGP_X_Gaussian(
        n = MC_samples,
        p = p,
        beta = beta,
        Sigma = Sigma,
        m = m,
        s = s
      )
    }
    
    # Compute estimands
    delta_estimands <- compute_delta(MC_data)
    theta_estimands <- compute_theta(MC_data)
    
    # Store results
    estimands$U_Y_MC[i] <- delta_estimands$U_Y
    estimands$U_S_MC[i] <- delta_estimands$U_S
    estimands$delta_MC[i] <- delta_estimands$delta
    estimands$V_Y_MC[i] <- theta_estimands$V_Y
    estimands$V_S_MC[i] <- theta_estimands$V_S
    estimands$theta_MC[i] <- theta_estimands$theta
  }
  
  return(estimands)
}

#' Monte Carlo Computation of the Estimands for the Simulation Study in Parast et al. (2024)
#'
#' This function iterates through the four simulation settings defined in Parast
#' et al. (2024) and estimates the true values of \eqn{U_Y}, \eqn{U_S},
#' \eqn{\delta}, \eqn{V_Y}, \eqn{V_S}, and \eqn{\theta} using a Monte Carlo
#' dataset generated according to the specified data-generating processes. 
#' 
#' @details
#' The settings are defined as follows:
#' \itemize{
#'   \item Setting 1: \strong{Useless surrogate (Gaussian model)}
#'     \deqn{Y_1 \sim \mathcal{N}(5, 3), \quad Y_0 \sim \mathcal{N}(3, 3),}
#'     \deqn{S_1 \sim \mathcal{N}(2/3, 1), \quad S_0 \sim \mathcal{N}(2/3, 1).}
#'   \item Setting 2: \strong{Perfect surrogate (Gaussian model)}
#'     \deqn{Y_1 \sim \mathcal{N}(6, 3), \quad Y_0 \sim \mathcal{N}(5/2, 3),}
#'     \deqn{S_1 = Y_1 + \mathcal{N}(0, 1/10), \quad S_0 = Y_0 + \mathcal{N}(0, 1/10).}
#'   \item Setting 3: \strong{Imperfect surrogate (Gaussian model)}
#'     \deqn{S_1 \sim \mathcal{N}(5, 3), \quad S_0 \sim \mathcal{N}(3, 3),}
#'     \deqn{Y_1 = S_1 + \mathcal{N}(1.5, 0.6), \quad Y_0 = S_0 + \mathcal{N}(0, 0.6).}
#'   \item Setting 4: \strong{Misspecified model (non-Gaussian model)}
#'     \deqn{S_1 \sim \exp(\mathcal{N}(2.5, 1.5)), \quad S_0 \sim \exp(\mathcal{N}(0.5, 1.5)),}
#'     \deqn{Y_1 = 2 + 6/5 \sqrt{S_1} + 3/10 \exp(S_1 / 500) + \exp(\mathcal{N}(0, 0.3)),}
#'     \deqn{Y_0 = 4/5 \sqrt{S_0} + 1/5 \exp(S_0 / 50) + \exp(\mathcal{N}(0, 0.3)).}
#' }
#' This function is generally not intended to be called directly by the user.
#' It is provided as a utility for computing the true parameter values for the
#' simulation settings described in \insertCite{parast2024rank;textual}{BSET}.
#'
#' @param MC_samples Integer. The number of Monte Carlo samples to generate per setting.
#'
#' @return A data frame containing the Monte Carlo estimates for each setting:
#' \itemize{
#'   \item \code{setting}: The index of the simulation setting.
#'   \item \code{U_Y_MC}, \code{U_S_MC}, \code{delta_MC}: Parameters of interest from \insertCite{parast2024rank;textual}{BSET}.
#'   \item \code{V_Y_MC}, \code{V_S_MC}, \code{theta_MC}: Parameters of interest from \insertCite{carlotti2026bayesian;textual}{BSET}.
#' }
#'
#' @references
#' \insertRef{parast2024rank}{BSET}
#' @export
compute_estimands_Parast_et_al_2024 <- function(MC_samples) {
  # Treatment assignment probability
  p = 0.5
  
  # Possible settings
  n_settings <- 4
  settings <- vector("list", n_settings)
  
  for (setting in 1:n_settings) {
    
    # Choice of the setting
    if (setting == 1) {
      
      #####################
      # Useless surrogate #
      #####################
      
      # Setting name
      setting_name <- "useless_surrogate"
      
      # Setting label
      setting_label <- "Useless Surrogate"
      
      # Model type
      model <- "Gaussian"
      
      # True parameters
      mu_star <- c(5, 2/3, 3, 2/3)
      Sigma_star <- diag(c(3, 1, 3, 1))
      
    } else if (setting == 2) {
      
      #####################
      # Perfect surrogate #
      #####################
      
      # Setting name
      setting_name <- "perfect_surrogate"
      
      # Setting label
      setting_label <- "Perfect Surrogate"
      
      # Model type
      model <- "Gaussian"
      
      # True parameters for Y and epsilon
      mu_Y <- c(6, 2.5)
      Sigma_Y <- 3*diag(2)
      
      mu_epsilon <- rep(0, 2)
      Sigma_epsilon <- 0.1*diag(2)
      
      mu_Y_epsilon <- c(mu_Y, mu_epsilon)
      Sigma_Y_epsilon <- rbind(
        cbind(Sigma_Y, matrix(0, 2, 2)),
        cbind(matrix(0, 2, 2), Sigma_epsilon)
      )
      
      # Mixing matrix
      A <- matrix(
        data = c(1, 0, 0, 0,
                 1, 0, 1, 0,
                 0, 1, 0, 0,
                 0, 1, 0, 1),
        nrow = 4,
        ncol = 4,
        byrow = TRUE
      )
      
      # True parameters
      mu_star <- A %*% mu_Y_epsilon
      Sigma_star <- A %*% Sigma_Y_epsilon %*% t(A)
      
    } else if (setting == 3) {
      
      #######################
      # Imperfect surrogate #
      #######################
      
      # Setting name
      setting_name <- "imperfect_surrogate"
      
      # Setting label
      setting_label <- "Imperfect Surrogate"
      
      # Model type
      model <- "Gaussian"
      
      # True parameters for S and epsilon
      mu_S <- c(5, 3)
      Sigma_S <- 3*diag(2)
      
      mu_epsilon <- c(1.5, 0)
      Sigma_epsilon <- 0.6*diag(2)
      
      mu_S_epsilon <- c(mu_S, mu_epsilon)
      Sigma_S_epsilon <- rbind(
        cbind(Sigma_S, matrix(0, 2, 2)),
        cbind(matrix(0, 2, 2), Sigma_epsilon)
      )
      
      # Mixing matrix
      A <- matrix(
        data = c(1, 0, 1, 0,
                 1, 0, 0, 0,
                 0, 1, 0, 1,
                 0, 1, 0, 0),
        nrow = 4,
        ncol = 4,
        byrow = TRUE
      )
      
      # True parameters
      mu_star <- A %*% mu_S_epsilon
      Sigma_star <- A %*% Sigma_S_epsilon %*% t(A)
      
    } else if (setting == 4) {
      
      ######################
      # Misspecified model #
      ######################
      
      # Setting name
      setting_name <- "misspecified"
      
      # Setting label
      setting_label <- "Misspecified Model"
      
      # Model type
      model <- "misspecified"
      
      # True parameters
      mu_star <- NULL
      Sigma_star <- NULL
      
    }
    
    settings[[setting]] <- list(
      setting_name = setting_name,
      setting_label = setting_label,
      model = model,
      mu_star = mu_star,
      Sigma_star = Sigma_star
    )
  }
  
  # Initialize estimands dataframe
  estimands <- data.frame(
    setting = 1:length(settings),
    U_Y_MC = as.numeric(NA),
    U_S_MC = as.numeric(NA),
    delta_MC = as.numeric(NA),
    V_Y_MC = as.numeric(NA),
    V_S_MC = as.numeric(NA),
    theta_MC = as.numeric(NA)
  )
  
  # Loop over settings
  for (i in 1:n_settings) {
    # Extract setting parameters
    model_type <- settings[[i]]$model
    mu_vals    <- settings[[i]]$mu_star
    sigma_vals <- settings[[i]]$Sigma_star
    
    # Generate Monte Carlo data
    MC_data <- DGP_no_X(
      n = MC_samples,
      p = p,
      mu_star = mu_vals,
      Sigma_star = sigma_vals,
      model = model_type
    )
    
    # Compute estimands
    delta_vals <- compute_delta(MC_data)
    theta_vals <- compute_theta(MC_data)
      
    # Store results
    estimands$U_Y_MC[i] <- delta_vals$U_Y
    estimands$U_S_MC[i] <- delta_vals$U_S
    estimands$delta_MC[i] <- delta_vals$delta
    estimands$V_Y_MC[i] <- theta_vals$V_Y
    estimands$V_S_MC[i] <- theta_vals$V_S
    estimands$theta_MC[i] <- theta_vals$theta
  }

  return(estimands)
}

#' True estimands for Parast et al. (2024)
#'
#' A dataset containing the Monte Carlo estimates of the parameters of interest
#' for the simulation settings considered in Parast et al. (2024).
#'
#' @format A data frame with 4 rows and 7 columns:
#' \describe{
#'   \item{setting}{The index of the simulation setting.}
#'   \item{U_Y_MC}{Numeric vector of Monte Carlo estimates.}
#'   \item{U_S_MC}{Numeric vector of Monte Carlo estimates.}
#'   \item{delta_MC}{Numeric vector of Monte Carlo estimates.}
#'   \item{V_Y_MC}{Numeric vector of Monte Carlo estimates.}
#'   \item{V_S_MC}{Numeric vector of Monte Carlo estimates.}
#'   \item{theta_MC}{Numeric vector of Monte Carlo estimates.}
#' }
#' @source Computed using the function \code{compute_estimands_Parast_et_al_2024(1000000)}.
"estimands_Parast_et_al_2024"

#' True estimands for Carlotti and Parast (2026)
#'
#' A dataset containing the Monte Carlo estimates of the parameters of interest
#' for the two simulation settings considered in Carlotti and Parast (2026):
#' setting 1 (binary covariate) and setting 2 (Gaussian covariate).
#'
#' @format A data frame with 2 rows and 7 columns:
#' \describe{
#'   \item{setting}{The index of the simulation setting.}
#'   \item{U_Y_MC}{Monte Carlo estimate of \eqn{U_Y = P(Y_{1i} > Y_{0j})}.}
#'   \item{U_S_MC}{Monte Carlo estimate of \eqn{U_S = P(S_{1i} > S_{0j})}.}
#'   \item{delta_MC}{Monte Carlo estimate of \eqn{\delta = U_Y - U_S}.}
#'   \item{V_Y_MC}{Monte Carlo estimate of \eqn{V_Y = P(Y_{1i} > Y_{0i})}.}
#'   \item{V_S_MC}{Monte Carlo estimate of \eqn{V_S = P(S_{1i} > S_{0i})}.}
#'   \item{theta_MC}{Monte Carlo estimate of \eqn{\theta = V_Y - V_S}.}
#' }
#' @source Computed using the function \code{compute_estimands_Carlotti_and_Parast_2026(1000000)}.
"estimands_Carlotti_and_Parast_2026"

#' Simulation grid for Parast et al. (2024)
#'
#' A dataset containing the grid of simulation results for Parast et al. (2024).
#'
#' @format A data frame with multiple columns:
#' \describe{
#'   \item{setting}{The index of the simulation setting.}
#'   \item{simulation}{The index of the simulation run.}
#'   \item{n_sample}{The sample size used.}
#'   \item{n_chains}{The number of MCMC chains used.}
#'   \item{n_iterations}{The number of MCMC iterations.}
#'   \item{n_simulations}{The total number of simulations.}
#'   \item{timestamp}{The timestamp of execution.}
#'   \item{seed}{The random seed used.}
#'   \item{BF_alternative}{The alternative hypothesis used for the Bayes factor.}
#'   \item{Bayesian_epsilon}{The threshold for the Bayesian test.}
#'   \item{frequentist_epsilon}{The threshold for the frequentist test.}
#'   \item{Bayesian_CI_upper}{The upper bound of the Bayesian credible interval.}
#'   \item{frequentist_CI_upper}{The upper bound of the frequentist confidence interval.}
#'   \item{Bayesian_coverage}{Logical. Indicates if the true value is in the credible interval.}
#'   \item{frequentist_coverage}{Logical. Indicates if the true value is in the confidence interval.}
#'   \item{Bayesian_power}{Logical. Indicates if the Bayesian test rejected the null.}
#'   \item{frequentist_power}{Logical. Indicates if the frequentist test rejected the null.}
#' }
#' @source Generated using the code in the \code{simulations} folder of the
#'   BSET GitHub repository (\url{https://github.com/PietroCarlotti/BSET}).
"Parast_et_al_2024_simulations_grid"

#' Simulation grid for Carlotti and Parast (2026)
#'
#' A dataset containing the grid of simulation results for Carlotti and
#' Parast (2026) across two covariate settings: a binary covariate setting
#' (setting 1) and a Gaussian covariate setting (setting 2). Each setting
#' is run for 500 simulations, for a total of 1000 rows.
#'
#' @format A data frame with 1000 rows and 17 columns:
#' \describe{
#'   \item{setting}{The index of the simulation setting: 1 for the binary
#'     covariate setting (\code{X_binary}) and 2 for the Gaussian covariate
#'     setting (\code{X_Gaussian}).}
#'   \item{simulation}{The index of the simulation run.}
#'   \item{n_sample}{The sample size used.}
#'   \item{n_chains}{The number of MCMC chains used.}
#'   \item{n_iterations}{The number of MCMC iterations.}
#'   \item{n_simulations}{The total number of simulations per setting.}
#'   \item{timestamp}{The timestamp of execution.}
#'   \item{seed}{The random seed used.}
#'   \item{BF_alternative}{The alternative hypothesis used for the Bayes factor.}
#'   \item{Bayesian_epsilon}{The threshold for the Bayesian test.}
#'   \item{frequentist_epsilon}{The threshold for the frequentist test.}
#'   \item{Bayesian_CI_upper}{The upper bound of the Bayesian credible interval.}
#'   \item{frequentist_CI_upper}{The upper bound of the frequentist confidence interval.}
#'   \item{Bayesian_coverage}{Logical. Indicates if the true value is in the credible interval.}
#'   \item{frequentist_coverage}{Logical. Indicates if the true value is in the confidence interval.}
#'   \item{Bayesian_power}{Logical. Indicates if the Bayesian test rejected the null.}
#'   \item{frequentist_power}{Logical. Indicates if the frequentist test rejected the null.}
#' }
#' @source Generated using the code in the \code{simulations} folder of the
#'   BSET GitHub repository (\url{https://github.com/PietroCarlotti/BSET}).
"Carlotti_and_Parast_2026_simulations_grid"

#' Compute the Distribution of the Bayes Factor from Carlotti and Parast (2026)
#'
#' This function calculates the probability mass function and cumulative distribution 
#' function of the Bayes factor defined in \insertCite{carlotti2026bayesian;textual}{BSET} for the
#' following hypothesis test:
#' \deqn{\begin{cases}
#' H_0: V_S = V_S^{0} \\
#' H_1: V_S > V_S^{0}
#' \end{cases}}
#' where \eqn{V_S} is the surrogate's treatment effect on \eqn{S} measured as
#' the probability
#' \deqn{V_S = P(S_{1i} > S_{0i})}
#' and \eqn{V_S^{0}} is a hypothesized value under the null hypothesis. These
#' hypotheses can be tested by fitting the following Beta-binomial model to the
#' data:
#' \deqn{\hat{V}_S \mid V_S \sim \text{Binomial} (n, V_S)}
#' \deqn{p(V_S) = \frac{\text{Beta}(V_S \mid a, b)}{\int_{1/2}^{1} \text{Beta}(v \mid a, b) \, dv}, \quad V_S \in \left(\tfrac{1}{2}, 1\right),}
#' where \eqn{\hat{V}_S} is the sample estimate of the surrogate's treatment
#' effect on \eqn{S} computed as
#' \deqn{\hat{V}_S = \frac{1}{n} \sum\limits^{n}_{i=1} I(S_{1i} > S_{0i}).}
#' The Bayes factor is then computed as the ratio of the marginal likelihoods
#' under the alternatives:
#' \deqn{BF_{n} = \frac{B(a + n \hat{V}_S,\, b + n - n \hat{V}_S) \left(1 - F_{\text{Beta}(a + n \hat{V}_S,\, b + n - n \hat{V}_S)}\!\left(\frac{1}{2}\right)\right)}{B(a, b) \left(1 - F_{\text{Beta}(a, b)}\!\left(\frac{1}{2}\right)\right)} \cdot 2^n,}
#' where \eqn{B(a, b)} is the Beta function, \eqn{F_{\text{Beta}(a,b)}} is the
#' cumulative distribution function of the \eqn{\text{Beta}(a, b)} distribution,
#' and \eqn{a} and \eqn{b} are the shape parameters of the Beta prior.
#' Given the true value of \eqn{V_S}, the distribution of the Bayes factor can
#' be computed by evaluating \eqn{BF_n} for all possible values of
#' \eqn{\hat{V}_S} and their corresponding probabilities under the Binomial
#' distribution with parameters \eqn{n} and the true value of \eqn{V_S}.
#' This function is generally not intended to be called directly by the user
#' and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
#'
#' @param n Integer. The sample size.
#' @param V_S_true Numeric. The true value of treatment effect on the surrogate.
#' @param V_S_zero Numeric. The hypothesized value of the surrogate's treatment effect under the null hypothesis (default is 0.5).
#' @param a Numeric. First shape parameter alpha for the Beta prior (default is 1).
#' @param b Numeric. Second shape parameter beta for the Beta prior (default is 1).
#' @param BF_alternative Character. The type of alternative hypothesis: either \code{"two_sided"} or \code{"greater"}.
#'
#' @return A data frame containing:
#' \itemize{
#'   \item \code{BF_values}: The possible values of the Bayes Factor.
#'   \item \code{BF_PMF}: The probability mass function for the Bayes Factor.
#'   \item \code{BF_CDF}: The cumulative distribution function for the Bayes Factor.
#' }
#' 
#' @references
#' \insertRef{carlotti2026bayesian}{BSET}
#' @importFrom stats pbeta dbinom
#' @importFrom dplyr %>% group_by summarise arrange mutate
#' @importFrom rlang .data
#' @export
compute_BF_distribution <- function(n, V_S_true, V_S_zero = 0.5, a = 1, b = 1, BF_alternative) {
  
  # Values of the Bayes Factor
  BF_values <- numeric(n + 1)
  
  for (k in 0:n) {
    # Log beta-binomial marginal likelihood under the alternative hypothesis
    if (BF_alternative == "two_sided") {
      log_marginal_H1 <- lbeta(a + k, b + n - k) - lbeta(a, b)
    } else if (BF_alternative == "greater") {
      log_marginal_H1 <- lbeta(a + k, b + n - k) - lbeta(a, b) + 
        log1p(- stats::pbeta(V_S_zero, a + k, b + n - k)) - 
        log1p(- stats::pbeta(V_S_zero, a, b))
    }
    
    # Log binomial marginal likelihood under the null hypothesis
    log_likelihood_H0 <- k * log(V_S_zero) + (n - k) * log(1 - V_S_zero)
    
    # Bayes Factor
    BF_values[k + 1] <- exp(log_marginal_H1 - log_likelihood_H0)
  }
  
  # Probabilities of observing each Bayes Factor value
  BF_probs <- stats::dbinom(
    x = 0:n,
    size = n,
    prob = V_S_true
  )
  
  # Tabulate the distribution of the Bayes Factor
  # Note: Using .data$ to avoid 'no visible binding for global variable' notes in check
  BF_distribution <- data.frame(
    BF_values = BF_values,
    BF_probs = BF_probs) %>%
    dplyr::group_by(.data$BF_values) %>% 
    dplyr::summarise(BF_PMF = sum(.data$BF_probs), .groups = "drop") %>% 
    dplyr::arrange(.data$BF_values) %>% 
    dplyr::mutate(BF_CDF = cumsum(.data$BF_PMF))
  
  return(BF_distribution)
}

---
title: "BSET Tutorial"
author: "Pietro Carlotti"
date: "`r Sys.Date()`"
output:
  bookdown::html_document2:
    toc: true
    toc_depth: 3
bibliography: references.bib
vignette: >
  %\VignetteIndexEntry{BSET Tutorial}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE)
```

## Introduction

`BSET` (Bayesian Surrogate Evaluation Test) is an `R` package for assessing the validity of surrogate markers in clinical trials. It provides hypothesis testing tools to evaluate whether a surrogate can reliably estimate the causal effect of a treatment on a primary outcome. The package implements the imputation-based Bayesian methodology of @carlotti2026bayesian, extending the frequentist rank-based approach of @parast2024rank. BSET addresses key limitations of the frequentist method, including the lack of causal interpretability and the inability to adjust for covariates in the estimation process.

The package supports Bayesian testing both with and without baseline covariates. Additionally, it includes comprehensive simulation suites to replicate studies from both papers, enabling performance comparisons between Bayesian and frequentist approaches across diverse clinical scenarios.

## Installation

The package is not yet available on CRAN, but you can install the development version of BSET from [GitHub](https://github.com/) with:

```{r install-BSET}
# install.packages("pak")
# pak::pak("PietroCarlotti/BSET")
```

To follow along with the examples in this tutorial, you will also need to install the following packages:

```{r packages, message=FALSE, warning=FALSE}
library(ggplot2)
library(dplyr)
```

## Quick Start

This section provides a minimal working example for readers who want to apply BSET to their data right away. The main function is `BSET`, which runs the test with or without adjusting for covariates depending on whether the `X` argument is provided. It requires a data frame with columns for the primary outcome `Y`, the surrogate `S`, and the treatment assignment `Z`. When `X` is provided, the model additionally adjusts for those baseline covariates.

To illustrate the usage of the package, we simulate a small dataset with a binary covariate:

```{r quick-start-data}
# Set the random seed for reproducibility
set.seed(1234)

# Sample size
n <- 50

# Binary covariate
X <- rbinom(n, 1, 0.5)

# Treatment assignment
Z <- rbinom(n, 1, 0.5)

# Primary outcome
Y <- 2 * Z -3 * X + rnorm(n)

# Surrogate outcome
S <- Y + rnorm(n)

df <- data.frame(
  Y = Y,
  S = S,
  Z = Z,
  X = X
)
```

To run BSET **without** adjusting for covariates, pass the data frame and the names of the relevant columns:

```{r quick-start-no-X, eval=FALSE}
result_no_X <- BSET::BSET(
  data = df,
  Y = "Y",
  S = "S",
  Z = "Z",
  seed = 123,
  plot = TRUE
)
result_no_X$theta_posterior_plot
```

```{r quick-start-no-X-show, echo=FALSE, out.width="100%", fig.align='center', fig.cap="Posterior distribution of $\\theta$ from `BSET` without covariates. Dashed lines show estimated quantities: the Bayesian 95\\% credible interval upper bound and threshold $\\eta$ (<span style='color:#0072B2'>blue shades</span>), and the frequentist 95\\% confidence interval upper bound and threshold $\\varepsilon$ (<span style='color:#D55E00'>orange shades</span>)."}
knitr::include_graphics("BSET_quick_start_no_X_plot.png")
```

To run BSET **with** a baseline covariate, add the covariate column name via the `X` argument:

```{r quick-start-X, eval=FALSE}
result_X <- BSET::BSET(
  data = df,
  Y = "Y",
  S = "S",
  Z = "Z",
  X = "X",
  seed = 123,
  plot = TRUE
)
result_X$theta_posterior_plot
```

```{r quick-start-X-show, echo=FALSE, out.width="100%", fig.align='center', fig.cap="Posterior distribution of $\\theta$ from `BSET`, adjusted for a baseline covariate. Dashed lines show estimated quantities: the Bayesian 95\\% credible interval upper bound and threshold $\\eta$ (<span style='color:#0072B2'>blue shades</span>), and the frequentist 95\\% confidence interval upper bound and threshold $\\varepsilon$ (<span style='color:#D55E00'>orange shades</span>)."}
knitr::include_graphics("BSET_quick_start_X_plot.png")
```

The function returns the posterior distribution of \(\theta\), the discrepancy between the treatment effects on \(Y\) and \(S\). Dashed lines in blue shades mark estimated Bayesian quantities: the upper bound of the 95% credible interval and the validation threshold \(\eta\). Dashed lines in orange shades mark estimated frequentist quantities: the upper bound of the 95% confidence interval and the threshold \(\varepsilon\) from @parast2024rank. Solid lines mark the true values: purple for \(\theta\) and pink for \(\delta\). If the Bayesian credible interval upper bound falls below the threshold \(\eta\), there is evidence that the surrogate is valid.

The rest of this tutorial explains how the data are generated, how the estimands \(\delta\) and \(\theta\) are computed, and how the validation threshold \(\eta\) is calibrated.

---

## Generating the data

We start by setting the random seed for reproducibility of the results.

```{r set-seed}
# Set the random seed for reproducibility
set.seed(1234)

# Sample size and treatment assignment probability used throughout
n <- 50
p <- 0.5
```

The package includes two functions to generate data for the simulations: `DGP` and `DGP_X`. The first one generates data from the simulation settings of @parast2024rank, which do not include covariates; the second one generates data which depends on a binary covariate \(X\) and is used for the simulations of @carlotti2026bayesian.

For example, this is how we can generate data from the second setting defined in @parast2024rank (i.e.: the setting where the surrogate is perfect and covariates are not included):

```{r generate-data-no-X}
# Mean vector of potential outcomes for the primary outcome and the surrogate
mu_star <- c(6, 6, 2.5, 2.5)

# Covariance matrix of potential outcomes for the primary outcome and the surrogate
Sigma_star <- kronecker(
  diag(2),
  matrix(
    data = c(3, 3,
             3, 3.1),
    nrow = 2,
    ncol = 2)
)

# Generate the data
data_no_X <- BSET::DGP_no_X(
  n = n,
  p = p,
  mu_star = mu_star,
  Sigma_star = Sigma_star,
  model = "Gaussian"
)
```

While this is how we can generate data from the first setting defined in @carlotti2026bayesian (i.e.: the setting where the surrogate is useful and covariates are included):

```{r generate-data-X}
# Binary covariate probability
q <- 0.5

# Mean vector for potential outcomes when X = 0 and when X = 1
mu_0 <- c(5, 5, 0, 0)
mu_1 <- c(5, -5, 0, -10)

# Covariance matrix for potential outcomes when X = 0 and when X = 1
Sigma_0 <- kronecker(
  diag(2),
  matrix(
    data = c(1, 1,
             1, 2),
    nrow = 2,
    ncol = 2)
  )

Sigma_1 <- kronecker(
  diag(2),
  matrix(
    data = c(1, 1,
             1, 2),
    nrow = 2,
    ncol = 2)
  )

# Generate the data
data_X <- BSET::DGP_X_binary(
  n = n,
  p = p,
  q = q,
  mu_0 = mu_0,
  mu_1 = mu_1,
  Sigma_0 = Sigma_0,
  Sigma_1 = Sigma_1
  )
```

## Computing the true values of the discrepancy parameters

Given the data generated with the above functions, we can estimate \(\delta\) and \(\theta\) using the `compute_delta` and `compute_theta` functions, respectively.

For example, for the data generated without covariates:

```{r compute-delta-theta-no-X}
# Compute delta
delta_no_X <- BSET::compute_delta(MC_data = data_no_X)

# Compute theta
theta_no_X <- BSET::compute_theta(MC_data = data_no_X)
```

And for the data generated with covariates:

```{r compute-delta-theta-X}
# Compute delta
delta_X <- BSET::compute_delta(MC_data = data_X)

# Compute theta
theta_X <- BSET::compute_theta(MC_data = data_X)
```

The estimated values of \(\delta\) and \(\theta\) are shown in the table below.

```{r delta-theta-table, echo=FALSE}
delta_theta_table <- data.frame(
  Setting = c("No X (Perfect Surrogate)", "Binary X"),
  "$\\widehat{\\delta}$" = c(delta_no_X$delta, delta_X$delta),
  "$\\widehat{\\theta}$" = c(theta_no_X$theta, theta_X$theta),
  check.names = FALSE 
)

knitr::kable(
  delta_theta_table, 
  caption = "Estimated values of $\\delta$ and $\\theta$ in the two settings.",
  escape = FALSE,
  booktabs = TRUE,
  align = "ccc",
  digits = 3
)
```

To determine the values of \(\delta\) and \(\theta\) for all the settings defined in the two papers, we use a large-scale Monte Carlo simulation via the `compute_estimands_Parast_et_al_2024` function for data without covariates [@parast2024rank], and the `compute_estimands_Carlotti_and_Parast_2026` function for data including covariates [@carlotti2026bayesian]. These functions run a Monte Carlo simulation with a large number of samples (e.g., 1,000,000) and can be called as follows:

```{r compute-delta-theta-true-code, eval=FALSE}
# Compute Monte Carlo estimands (based on 1,000,000 samples) — this is slow
estimands_Parast_et_al_2024 <- BSET::compute_estimands_Parast_et_al_2024(n_MC = 1000000)
estimands_Carlotti_and_Parast_2026 <- BSET::compute_estimands_Carlotti_and_Parast_2026(n_MC = 1000000)
```

For the purpose of this tutorial, we load the precomputed versions shipped with the package:

```{r compute-delta-theta-true}
# Load precomputed Monte Carlo estimands (based on 1,000,000 samples)
estimands_Parast_et_al_2024 <- BSET::estimands_Parast_et_al_2024
estimands_Carlotti_and_Parast_2026 <- BSET::estimands_Carlotti_and_Parast_2026
```

As shown in the table below, \(\delta\) and \(\theta\) yield identical values (up to Monte Carlo error) across all settings. Both estimands are close to \(0\) for a perfect surrogate, they are significantly higher for a useless surrogate, and take intermediate values for imperfect surrogates or misspecified models.

```{r estimands-Parast-et-al-2024, echo=FALSE}
estimands_Parast_et_al_2024_table <- data.frame(
  Setting = c("Useless surrogate", "Perfect surrogate", "Imperfect surrogate", "Misspecified model"),
  "$\\delta$" = estimands_Parast_et_al_2024$delta_MC,
  "$\\theta$" = estimands_Parast_et_al_2024$theta_MC,
  check.names = FALSE
)

knitr::kable(
  estimands_Parast_et_al_2024_table,
  caption = "Monte Carlo estimates of $\\delta$ and $\\theta$ for the simulation settings considered in Parast et al. (2024).",
  booktabs = TRUE,
  align = "ccc",
  digits = 3
)
```

Whereas, as shown in the table below, when we include covariates in the data generating process, \(\delta\) and \(\theta\) yield different values. In particular, while \(\theta\) is close to \(0\) for a perfect surrogate, \(\delta\) is significantly higher.

```{r estimands-Carlotti-and-Parast-2026, echo=FALSE}
estimands_Carlotti_and_Parast_2026_table <- data.frame(
  Setting = c("Perfect surrogate"),
  "$\\delta$" = estimands_Carlotti_and_Parast_2026$delta_MC,
  "$\\theta$" = estimands_Carlotti_and_Parast_2026$theta_MC,
  check.names = FALSE
)

knitr::kable(
  estimands_Carlotti_and_Parast_2026_table,
  caption = "Monte Carlo estimates of $\\delta$ and $\\theta$ for the simulation settings considered in Carlotti and Parast (2026).",
  booktabs = TRUE,
  align = "ccc",
  digits = 3
)
```

## Computing the validation threshold

The validation threshold \(\eta\) is the value of \(\theta\) below which the surrogate is considered valid. As explained in @carlotti2026bayesian, the computation of \(\eta\) is based on the distribution of the following Bayes factor:
\[
  BF_{n} = \frac{1 - F_{\text{Beta} \left( a + n \hat{V}_{S}, \, b + n - n \hat{V}_{S} \right)} \left( \frac{1}{2} \right)}{1 - F_{\text{Beta} \left( a, \, b \right)} \left( \frac{1}{2} \right)}.
\]
Given the true value of \(V_S\), the distribution of \(BF_n\) can be computed with the function `compute_BF_distribution`. For example, the distribution of the Bayes factor under the null hypothesis \(V_S = 0.5\) can be computed as follows:

```{r compute-BF-distribution}
# Hypothesized value of V_S under the null
V_S_zero <- 0.5

# Prior parameters for the Beta distribution
a <- 1
b <- 1

# Alternative hypothesis for the Bayes factor
BF_alternative <- "greater"

# Compute the distribution of the Bayes factor
BF_distribution <- BSET::compute_BF_distribution(
  n = n,
  V_S_true = V_S_zero,
  V_S_zero = V_S_zero,
  a = a,
  b = b,
  BF_alternative = BF_alternative
)
```

The distribution of the Bayes factor under the null hypothesis is shown in the figure below. Since the Bayes factor can take values on a very wide range, we plot the distribution on the log scale.

```{r BF-distribution-plot, echo=FALSE, fig.width=8, fig.height=4.5, fig.align='center', fig.cap="Distribution of the Bayes factor under the null hypothesis $V_S = 0.5$."}
# Log transform the Bayes factor
BF_distribution$log_BF_values <- log(BF_distribution$BF_values)

ggplot(BF_distribution, aes(x = log_BF_values, y = BF_PMF)) +
  geom_col(fill = "steelblue", width = 0.07) +
  labs(
    x = expression(log(BF[n])),
    y = "PMF"
  ) +
  theme_minimal()
```

Given the distribution of the Bayes factor under the null hypothesis, we can compute the critical value \(BF_{n, \alpha}\) corresponding to a specified Type I error rate \(\alpha\).

```{r compute-BF-alpha}
# Type I error rate
alpha <- 0.05

# Compute the critical value of the Bayes factor corresponding to alpha
BF_alpha <- BF_distribution %>%
    dplyr::filter(BF_CDF >= 1 - alpha) %>%
    dplyr::slice(1) %>%
    dplyr::pull(BF_values)
```

For example, for \(\alpha = 0.05\) we have

\[
  BF_{n, \alpha} = `r round(BF_alpha, 3)`.
\]

Once we have the value of \(BF_{n, \alpha}\), we can compute the value of \(v_S\) that satisfies the following equation:

\[
  P(\text{BF}_n \geq \text{BF}_{n, \alpha} \; | \; V_S = v_S) = 1 - \beta,
\]

where \(1 - \beta\) is the desired power of the test. A root-finding algorithm is used to solve for the value of \(v_S\) that satisfies the above equation, which is implemented in the function `compute_V_S_star`.

For example, for a Type II error rate of \(\beta = 0.2\), we can compute the value of \(v_S\) as follows:

```{r compute-V_S-star}
# Type II error rate
beta <- 0.2

# Compute the value of v_S that satisfies the power constraint
V_S_star <- BSET::compute_V_S_star(
  n = n,
  alpha = alpha,
  beta = beta,
  V_S_zero = V_S_zero,
  a = a,
  b = b,
  BF_alternative = BF_alternative,
  root_tolerance = 1e-16
)$V_S_star
```

Then, we have that

\[
  v_S = `r round(V_S_star, 3)`.
\]

Finally, the validation threshold \(\eta\) can be computed as

\[
  \eta = \max \{v_Y - v_S, 0\},
\]

where \(v_Y\) is the hypothesized value of the treatment effect on the primary outcome (typically set equal to the estimate computed on the available data).

For example, we can set \(v_Y\) equal to the Monte Carlo estimate of \(V_Y\) for setting 1 of @parast2024rank (i.e.: the setting where the surrogate is perfect and covariates are not included).

```{r compute-eta}
# Hypothesized value of the treatment effect on the primary outcome
v_Y <- estimands_Parast_et_al_2024$V_Y_MC[2]

# Compute the validation threshold eta
eta <- max(v_Y - V_S_star, 0)
```

In this case, we have that

\[
  \eta = `r round(eta, 3)`.
\]

## Running the BSET procedure

The package includes the function `BSET` to run the BSET procedure. When the `X` argument is omitted (or set to `NULL`), the procedure runs without adjusting for covariates; when `X` is provided, it adjusts for the specified baseline covariates.

The result of the procedure is summarized by the posterior distribution of $\theta$ and its 95% credible interval. In general, if the upper bound of the credible interval falls below the validation threshold $\eta$, the BSET procedure concludes that there is evidence that the surrogate is valid. If instead the upper bound exceeds $\eta$, the procedure does not find sufficient evidence of surrogacy.

### BSET with no covariates

As an example, we can run the BSET procedure without adjusting for covariates on the data generated from the second setting of @parast2024rank. First of all, we need to prepare the data in the format required by `BSET`: a data frame with three columns, where the first column contains the observed values of the primary outcome \(Y\), the second column contains the observed values of the surrogate \(S\), and the third column contains the treatment assignment \(Z\).

```{r BSET-no-X-data}
# Prepare the data for BSET (no covariates)
BSET_no_X_data <- data.frame(
  Y = data_no_X$P_observed[, "Y"],
  S = data_no_X$P_observed[, "S"],
  Z = data_no_X$Z 
)
```

We also need to define the posterior sampling parameters:

* `n_chains`: The number of MCMC chains to run.
* `n_iter`: The total number of MCMC iterations to run for each chain.
* `burn_in_ratio`: The proportion of MCMC iterations to discard as burn-in.

```{r BSET-no-X-posterior-sampling-parameters}
# Posterior sampling parameters
n_chains <- 2
n_iter <- 2000
burn_in_ratio <- 0.25
```

Then, we need to define the prior parameters for the distribution of the potential outcomes in our Bayesian model. In particular, we need to specify:

*  `mu_0`: A numeric vector of length 4 containing the prior means for the potential outcomes.
* `Sigma_0`: A numeric positive-definite matrix of dimension \(4 \times 4\) containing the prior covariance matrix for the potential outcomes.
* `s`: A numeric vector of length 4 containing the prior scale parameters for the potential outcomes.
* `tau`: A numeric scalar containing the prior scale parameter for the correlation matrix of the potential outcomes.

```{r BSET-no-X-prior-parameters}
# Prior parameters
mu_0 <- rep(0, 4)
Sigma_0 <- diag(4)
s <- rep(1, 4)
tau <- 1
```

If the true values of \(\delta\) and \(\theta\) are known, we can also specify them as input to `BSET` to check whether they are included in the posterior credible intervals. In this case, we can set \(\delta\) and \(\theta\) equal to the Monte Carlo estimates for setting 2 of Parast et al. (2024).

We can also specify some additional parameters for the BSET procedure, such as:

* `seed`: An integer scalar to set the random seed for reproducibility of the MCMC sampling process.
* `plot`: A logical scalar indicating whether to plot the posterior distribution of \(\theta\).
* `mute`: A logical scalar indicating whether to suppress the output of the MCMC sampling process.
* `parallel`: A logical scalar indicating whether to run the MCMC sampling process in parallel or sequentially.

Finally, we can run the BSET procedure without adjusting for covariates as follows:

```{r BSET-no-X, eval=FALSE}
# Run the BSET procedure without adjusting for covariates
BSET_no_X_results <- BSET::BSET(
  data = BSET_no_X_data,
  Y = "Y",
  S = "S",
  Z = "Z",
  delta_true = estimands_Parast_et_al_2024$delta_MC[2],
  theta_true = estimands_Parast_et_al_2024$theta_MC[2],
  seed = 123,
  n_chains = n_chains,
  n_iter = n_iter,
  burn_in_ratio = burn_in_ratio,
  a = a,
  b = b,
  alpha = alpha,
  beta = beta,
  V_S_zero = V_S_zero,
  BF_alternative = BF_alternative,
  root_tolerance = 1e-16,
  mu_0 = mu_0,
  Sigma_0 = Sigma_0,
  s = s,
  tau = tau,
  plot = TRUE,
  mute = TRUE,
  parallel = TRUE
)
```

```{r BSET-no-X-load, include=FALSE}
```

The posterior distribution of \(\theta\) from the BSET procedure without adjusting for covariates is shown in the figure below.

```{r BSET-no-X-plot, echo=FALSE, out.width="100%", fig.align='center', fig.cap="Posterior distribution of $\\theta$ from the BSET procedure without adjusting for covariates. Dashed lines show estimated quantities: the Bayesian 95\\% credible interval upper bound and threshold $\\eta$ (<span style='color:#0072B2'>blue shades</span>), and the frequentist 95\\% confidence interval upper bound and threshold $\\varepsilon$ (<span style='color:#D55E00'>orange shades</span>). Solid lines show the true values of $\\theta$ (<span style='color:#551A8B'>purple</span>) and $\\delta$ (<span style='color:#CC79A7'>pink</span>)."}
knitr::include_graphics("BSET_no_X_plot.png")
```

Two features of this result are worth highlighting. First, the posterior distribution of $\theta$ is centered around the true value of $\theta$, demonstrating that the Bayesian imputation approach accurately recovers the true discrepancy between the treatment effects on $Y$ and $S$. In this setting, covariates do not play a role in the data generating process, so the frequentist estimand $\delta$ coincides with $\theta$ and both methods perform similarly. Second, since the upper bound of the 95% credible interval falls below the validation threshold $\eta$, the BSET procedure concludes that there is evidence that the surrogate is valid in this setting.

### BSET with covariates
As an example, we can run the BSET procedure adjusting for covariates on the data generated from the first setting of @carlotti2026bayesian. First of all, we need to prepare the data in the format required by `BSET`: a data frame with four columns, where the first column contains the observed values of the primary outcome \(Y\), the second column contains the observed values of the surrogate \(S\), the third column contains the treatment assignment \(Z\), and the fourth column contains the values of the binary covariate \(X\). We call \(d\) the number of covariates, which in this case is equal to \(2\) (including the intercept).

```{r BSET-X-data}
# Prepare the data for BSET (with covariates)
BSET_X_data <- data.frame(
  Y = data_X$P_observed[, "Y"],
  S = data_X$P_observed[, "S"],
  Z = data_X$Z,
  X = data_X$X
)
```

The posterior sampling parameters are defined in the same way as for the BSET procedure without adjusting for covariates. Whereas the prior parameters for the distribution of the potential outcomes in our Bayesian model are defined as follows:

* `mu_beta`: A numeric vector of length \(d\) containing the prior means for the regression coefficients of the potential outcomes on the covariates.
* `Sigma_beta`: A numeric positive-definite matrix of dimension \(d \times d\) containing the prior covariance matrix for the regression coefficients of the potential outcomes on the covariates.

```{r BSET-X-prior-parameters}
# Prior parameters for the regression coefficients of the potential outcomes on the covariates
d <- 2
mu_beta <- rep(0, d)
Sigma_beta <- 10*diag(d)
```

We can also specify the true values of \(\delta\) and \(\theta\) as input to `BSET` to check if they are included in the posterior credible intervals. In this case, we can set \(\delta\) and \(\theta\) equal to the Monte Carlo estimates of \(\delta\) and \(\theta\) for setting 1 of @carlotti2026bayesian.

Finally, we can run the BSET procedure adjusting for covariates as follows:

```{r BSET-X, eval=FALSE}
# Run the BSET procedure adjusting for covariates
BSET_X_results <- BSET::BSET(
  data = BSET_X_data,
  Y = "Y",
  S = "S",
  Z = "Z",
  X = "X",
  delta_true = estimands_Carlotti_and_Parast_2026$delta_MC[1],
  theta_true = estimands_Carlotti_and_Parast_2026$theta_MC[1],
  seed = 123,
  n_chains = n_chains,
  n_iter = n_iter,
  burn_in_ratio = burn_in_ratio,
  a = a,
  b = b,
  alpha = alpha,
  beta = beta,
  V_S_zero = V_S_zero,
  BF_alternative = BF_alternative,
  root_tolerance = 1e-16,
  mu_beta = mu_beta,
  Sigma_beta = Sigma_beta,
  s = s,
  tau = tau,
  plot = TRUE,
  mute = TRUE,
  parallel = TRUE
)
```

```{r BSET-X-load, include=FALSE}
```

The posterior distribution of \(\theta\) from the BSET procedure adjusting for covariates is shown in the figure below.

```{r BSET-X-plot, echo=FALSE, out.width="100%", fig.align='center', fig.cap="Posterior distribution of $\\theta$ from the BSET procedure adjusting for covariates. Dashed lines show estimated quantities: the Bayesian 95\\% credible interval upper bound and threshold $\\eta$ (<span style='color:#0072B2'>blue shades</span>), and the frequentist 95\\% confidence interval upper bound and threshold $\\varepsilon$ (<span style='color:#D55E00'>orange shades</span>). Solid lines show the true values of $\\theta$ (<span style='color:#551A8B'>purple</span>) and $\\delta$ (<span style='color:#CC79A7'>pink</span>)."}
knitr::include_graphics("BSET_X_plot.png")
```

Unlike the previous setting, covariates now play a role in the data generating process, and this is where the two methods diverge. The posterior distribution of $\theta$ is still centered around its true value, confirming that the covariate-adjusted Bayesian model correctly recovers the true discrepancy parameter. In contrast, the frequentist estimand $\delta$ diverges substantially from the true $\theta$, illustrating a key limitation of rank-based methods when covariates are present. Since the upper bound of the 95% credible interval falls below the validation threshold $\eta$, the BSET procedure correctly concludes that there is evidence that the surrogate is valid in this setting, while the frequentist method, being based on $\delta$, would incorrectly conclude that it is not.

## References

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{Carlotti_and_Parast_2026_simulations_grid}
\alias{Carlotti_and_Parast_2026_simulations_grid}
\title{Simulation grid for Carlotti and Parast (2026)}
\format{
A data frame with 1000 rows and 17 columns:
\describe{
  \item{setting}{The index of the simulation setting: 1 for the binary
    covariate setting (\code{X_binary}) and 2 for the Gaussian covariate
    setting (\code{X_Gaussian}).}
  \item{simulation}{The index of the simulation run.}
  \item{n_sample}{The sample size used.}
  \item{n_chains}{The number of MCMC chains used.}
  \item{n_iterations}{The number of MCMC iterations.}
  \item{n_simulations}{The total number of simulations per setting.}
  \item{timestamp}{The timestamp of execution.}
  \item{seed}{The random seed used.}
  \item{BF_alternative}{The alternative hypothesis used for the Bayes factor.}
  \item{Bayesian_epsilon}{The threshold for the Bayesian test.}
  \item{frequentist_epsilon}{The threshold for the frequentist test.}
  \item{Bayesian_CI_upper}{The upper bound of the Bayesian credible interval.}
  \item{frequentist_CI_upper}{The upper bound of the frequentist confidence interval.}
  \item{Bayesian_coverage}{Logical. Indicates if the true value is in the credible interval.}
  \item{frequentist_coverage}{Logical. Indicates if the true value is in the confidence interval.}
  \item{Bayesian_power}{Logical. Indicates if the Bayesian test rejected the null.}
  \item{frequentist_power}{Logical. Indicates if the frequentist test rejected the null.}
}
}
\source{
Generated using the code in the \code{simulations} folder of the
  BSET GitHub repository (\url{https://github.com/PietroCarlotti/BSET}).
}
\usage{
Carlotti_and_Parast_2026_simulations_grid
}
\description{
A dataset containing the grid of simulation results for Carlotti and
Parast (2026) across two covariate settings: a binary covariate setting
(setting 1) and a Gaussian covariate setting (setting 2). Each setting
is run for 500 simulations, for a total of 1000 rows.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_BF_distribution.R
\name{compute_BF_distribution}
\alias{compute_BF_distribution}
\title{Compute the Distribution of the Bayes Factor from Carlotti and Parast (2026)}
\usage{
compute_BF_distribution(
  n,
  V_S_true,
  V_S_zero = 0.5,
  a = 1,
  b = 1,
  BF_alternative
)
}
\arguments{
\item{n}{Integer. The sample size.}

\item{V_S_true}{Numeric. The true value of treatment effect on the surrogate.}

\item{V_S_zero}{Numeric. The hypothesized value of the surrogate's treatment effect under the null hypothesis (default is 0.5).}

\item{a}{Numeric. First shape parameter alpha for the Beta prior (default is 1).}

\item{b}{Numeric. Second shape parameter beta for the Beta prior (default is 1).}

\item{BF_alternative}{Character. The type of alternative hypothesis: either \code{"two_sided"} or \code{"greater"}.}
}
\value{
A data frame containing:
\itemize{
  \item \code{BF_values}: The possible values of the Bayes Factor.
  \item \code{BF_PMF}: The probability mass function for the Bayes Factor.
  \item \code{BF_CDF}: The cumulative distribution function for the Bayes Factor.
}
}
\description{
This function calculates the probability mass function and cumulative distribution 
function of the Bayes factor defined in \insertCite{carlotti2026bayesian;textual}{BSET} for the
following hypothesis test:
\deqn{\begin{cases}
H_0: V_S = V_S^{0} \\
H_1: V_S > V_S^{0}
\end{cases}}
where \eqn{V_S} is the surrogate's treatment effect on \eqn{S} measured as
the probability
\deqn{V_S = P(S_{1i} > S_{0i})}
and \eqn{V_S^{0}} is a hypothesized value under the null hypothesis. These
hypotheses can be tested by fitting the following Beta-binomial model to the
data:
\deqn{\hat{V}_S \mid V_S \sim \text{Binomial} (n, V_S)}
\deqn{p(V_S) = \frac{\text{Beta}(V_S \mid a, b)}{\int_{1/2}^{1} \text{Beta}(v \mid a, b) \, dv}, \quad V_S \in \left(\tfrac{1}{2}, 1\right),}
where \eqn{\hat{V}_S} is the sample estimate of the surrogate's treatment
effect on \eqn{S} computed as
\deqn{\hat{V}_S = \frac{1}{n} \sum\limits^{n}_{i=1} I(S_{1i} > S_{0i}).}
The Bayes factor is then computed as the ratio of the marginal likelihoods
under the alternatives:
\deqn{BF_{n} = \frac{B(a + n \hat{V}_S,\, b + n - n \hat{V}_S) \left(1 - F_{\text{Beta}(a + n \hat{V}_S,\, b + n - n \hat{V}_S)}\!\left(\frac{1}{2}\right)\right)}{B(a, b) \left(1 - F_{\text{Beta}(a, b)}\!\left(\frac{1}{2}\right)\right)} \cdot 2^n,}
where \eqn{B(a, b)} is the Beta function, \eqn{F_{\text{Beta}(a,b)}} is the
cumulative distribution function of the \eqn{\text{Beta}(a, b)} distribution,
and \eqn{a} and \eqn{b} are the shape parameters of the Beta prior.
Given the true value of \eqn{V_S}, the distribution of the Bayes factor can
be computed by evaluating \eqn{BF_n} for all possible values of
\eqn{\hat{V}_S} and their corresponding probabilities under the Binomial
distribution with parameters \eqn{n} and the true value of \eqn{V_S}.
This function is generally not intended to be called directly by the user
and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
}
\references{
\insertRef{carlotti2026bayesian}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/frequentist_test.R
\name{frequentist_test}
\alias{frequentist_test}
\title{Frequentist Test from Parast et al. (2024)}
\usage{
frequentist_test(P_observed, Z, alpha = 0.05, beta = 0.2, delta_true = NULL)
}
\arguments{
\item{P_observed}{Observed outcomes \eqn{(Y, S)} corresponding to the assigned treatment \eqn{Z}.}

\item{Z}{Treatment assignment vector.}

\item{alpha}{Numeric. Significance level for the confidence interval (default is 0.05).}

\item{beta}{Numeric. Type II error rate (default is 0.2).}

\item{delta_true}{Numeric (optional). The true value of \eqn{\delta}, used to calculate 
frequentist coverage during simulations.}
}
\value{
A list containing:
\itemize{
  \item \code{CI}: The calculated confidence interval for \eqn{\delta}.
  \item \code{threshold}: The \eqn{\varepsilon} threshold value used in the test.
  \item \code{coverage}: Logical indicating if \code{delta_true} falls within the \code{CI}
    (if \code{delta_true} is provided).
  \item \code{power}: Logical indicating if the upper bound of \code{CI} is below \code{threshold}, which indicates that the test identifies the surrogate as valid.
}
}
\description{
This function performs a frequentist test for surrogate evaluation based on 
the rank-based methodology of \insertCite{parast2024rank;textual}{BSET}. It calculates confidence
intervals, the \eqn{\varepsilon} threshold used, and determines if the surrogate is
valid.
This function is generally not intended to be called directly by the user
and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
}
\references{
\insertRef{parast2024rank}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_estimands_Carlotti_and_Parast_2026.R
\name{compute_estimands_Carlotti_and_Parast_2026}
\alias{compute_estimands_Carlotti_and_Parast_2026}
\title{Monte Carlo Computation of the Estimands for the Simulation Study in Carlotti and Parast (2026)}
\usage{
compute_estimands_Carlotti_and_Parast_2026(MC_samples)
}
\arguments{
\item{MC_samples}{Integer. The number of Monte Carlo samples to generate per setting.}
}
\value{
A data frame containing the Monte Carlo estimates for each setting:
\itemize{
  \item \code{setting}: The index of the simulation setting.
  \item \code{U_Y_MC}, \code{U_S_MC}, \code{delta_MC}: Parameters of interest from \insertCite{parast2024rank;textual}{BSET}.
  \item \code{V_Y_MC}, \code{V_S_MC}, \code{theta_MC}: Parameters of interest from \insertCite{carlotti2026bayesian;textual}{BSET}.
}
}
\description{
This function iterates through the simulation settings defined in Carlotti
and Parast (2026) and estimates the true values of \eqn{U_Y}, \eqn{U_S},
\eqn{\delta}, \eqn{V_Y}, \eqn{V_S}, and \eqn{\theta} using a Monte Carlo
dataset generated according to the specified data-generating processes.
}
\details{
The settings are defined as follows:
\itemize{
  \item Setting 1: \strong{X binary}
  \itemize{
    \item If \eqn{X = 1}:
    \deqn{Y_1 \sim \mathcal{N}(5, 1), \quad Y_0 \sim \mathcal{N}(0, 1)}
    \deqn{S_1 = Y_1 + \mathcal{N}(0, 1), \quad S_0 = Y_0 + \mathcal{N}(0, 1)}
    \item If \eqn{X = 0}:
    \deqn{Y_1 \sim \mathcal{N}(5, 1), \quad Y_0 \sim \mathcal{N}(0, 1)}
    \deqn{S_1 = Y_1 + \mathcal{N}(-10, 1), \quad S_0 = Y_0 + \mathcal{N}(-10, 1)}
  }
  \item Setting 2: \strong{X Gaussian}
  \deqn{(Y_1, S_1, Y_0, S_0) \mid X = x \sim \mathcal{N}(x (1, 7, 0, 6)', \frac{1}{2} I_4),}
}
This function is generally not intended to be called directly by the user.
It is provided as a utility for computing the true parameter values for the
simulation settings described in \insertCite{carlotti2026bayesian;textual}{BSET}.
}
\references{
\insertRef{carlotti2026bayesian}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Bayesian_test.R
\name{Bayesian_test}
\alias{Bayesian_test}
\title{Bayesian Test from Carlotti and Parast (2026)}
\usage{
Bayesian_test(
  P_MCMC,
  alpha = 0.05,
  V_S_star,
  theta_true = NULL,
  V_Y_true = NULL
)
}
\arguments{
\item{P_MCMC}{A three-dimensional array of potential outcomes obtained via MCMC sampling with dimensions \code{[n_subjects, variables, n_samples]}. The variables should correspond to \eqn{(Y_1, S_1, Y_0, S_0)}.}

\item{alpha}{Numeric. Significance level for the credible interval (default is 0.05).}

\item{V_S_star}{Numeric. The value of \eqn{v_S} that satisfies the power constraint for the surrogate validation test.}

\item{theta_true}{Numeric (optional). The true value of \eqn{\eta}, used to calculate frequentist coverage during simulations.}

\item{V_Y_true}{Numeric (optional). The true value of \eqn{V_Y}, used to calculate the surrogate validation threshold \eqn{\eta} during simulations. If not provided, it will be estimated from the MCMC samples.}
}
\value{
A list containing:
\itemize{
  \item \code{V_Y_MCMC}: Posterior draws for \eqn{V_Y}.
  \item \code{V_S_MCMC}: Posterior draws for \eqn{V_S}.
  \item \code{theta_MCMC}: Posterior draws for \eqn{\theta = V_Y - V_S}.
  \item \code{CI}: The calculated credible interval for \eqn{\theta}.
  \item \code{threshold}: The \eqn{\eta} threshold value used in the test.
  \item \code{coverage}: Logical indicating if \code{theta_true} falls within the \code{CI} (if \code{theta_true} is provided).
  \item \code{power}: Logical indicating if the upper bound of \code{CI} is below \code{threshold}, which indicates that the test identifies the surrogate as valid.
}
}
\description{
This function performs a Bayesian test for surrogate evaluation based on the
imputation-based methodology of \insertCite{carlotti2026bayesian;textual}{BSET}. It calculates
credible intervals, the \eqn{\eta} threshold used, and determines if the
surrogate is valid.
This function is generally not intended to be called directly by the user
and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
}
\references{
\insertRef{carlotti2026bayesian}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BSET.R
\name{BSET}
\alias{BSET}
\title{Bayesian Surrogate Evaluation Test from Carlotti and Parast (2026)}
\usage{
BSET(
  data,
  Y,
  S,
  Z,
  X = NULL,
  delta_true = NULL,
  theta_true = NULL,
  seed = NULL,
  n_chains = 4,
  n_iter = 2000,
  burn_in_ratio = 0.25,
  a = 1,
  b = 1,
  alpha = 0.05,
  beta = 0.2,
  V_S_zero = 0.5,
  BF_alternative = "greater",
  root_tolerance = 1e-16,
  mu_0 = rep(0, 4),
  Sigma_0 = diag(4),
  intercept = TRUE,
  mu_beta = NULL,
  Sigma_beta = NULL,
  s = rep(1, 4),
  tau = 1,
  plot = FALSE,
  mute = TRUE,
  parallel = TRUE
)
}
\arguments{
\item{data}{A data frame containing the observed data.}

\item{Y}{Character. Name of the outcome variable.}

\item{S}{Character. Name of the surrogate variable.}

\item{Z}{Character. Name of the treatment assignment variable.}

\item{X}{Character vector. Names of the covariate columns to include in the model.
When \code{NULL} (the default), the model is fit without covariates and the
\code{mu_0} / \code{Sigma_0} prior parameters are used. When provided, the
covariate-adjusted model is fit and the \code{intercept} / \code{mu_beta} /
\code{Sigma_beta} prior parameters are used instead.}

\item{delta_true}{The true value of delta, used to calculate frequentist coverage during simulations (optional).}

\item{theta_true}{The true value of theta, used to calculate Bayesian coverage during simulations (optional).}

\item{seed}{Random seed for reproducibility (optional. If not provided, a random seed will be generated).}

\item{n_chains}{Number of MCMC chains to run (default is 4).}

\item{n_iter}{Number of iterations per MCMC chain (default is 2000).}

\item{burn_in_ratio}{Proportion of iterations to discard as burn-in (default is 0.25).}

\item{a, b}{Prior parameters for prior Beta distribution on V_S (default is a = 1, b = 1).}

\item{alpha}{Type I error rate for the test (default is 0.05).}

\item{beta}{Type II error rate for the test (default is 0.2).}

\item{V_S_zero}{Value of V_S under the null hypothesis (default is 0.5).}

\item{BF_alternative}{Alternative hypothesis for the Bayes factor test ("greater", "less" or "two.sided").}

\item{root_tolerance}{Numerical tolerance for root-finding algorithms (default is 1e-16).}

\item{mu_0}{Prior mean vector for the mean parameters. Used only when \code{X = NULL}
(default is a vector of zeros of length 4).}

\item{Sigma_0}{Prior covariance matrix for the mean vector. Used only when \code{X = NULL}
(default is a 4x4 identity matrix).}

\item{intercept}{Logical. Whether to include an intercept in the regression model.
Used only when \code{X} is provided (default is \code{TRUE}).}

\item{mu_beta}{Prior mean vector for the regression coefficients. Used only when \code{X}
is provided (default is a vector of zeros with length equal to the number of covariates,
including the intercept if \code{intercept = TRUE}).}

\item{Sigma_beta}{Prior covariance matrix for the regression coefficients. Used only when
\code{X} is provided (default is a diagonal matrix with variance 10, with dimensions equal
to the number of covariates, including the intercept if \code{intercept = TRUE}).}

\item{s}{Prior scale parameters for the error variance (default is a vector of ones of length 4).}

\item{tau}{Prior parameter for the LKJ correlation distribution (default is 1).}

\item{plot}{Logical. Whether to plot the posterior distribution of theta (default is FALSE).}

\item{mute}{Logical. Whether to suppress Stan output during model fitting (default is TRUE).}

\item{parallel}{Logical. Whether to use parallel processing for MCMC sampling (default is TRUE).}
}
\value{
A list containing:
\itemize{
 \item \code{stan_cores}: The number of CPU cores used for MCMC sampling.
 \item \code{Bayesian_test}: A list containing the results of the Bayesian test, including posterior samples and credible intervals.
 \item \code{frequentist_test}: A list containing the results of the frequentist test, including point estimates and confidence intervals.
 \item \code{theta_posterior_plot}: A \code{ggplot} object showing the posterior distribution of \eqn{\theta}, with vertical lines indicating the credible interval, the \eqn{\eta} threshold, and the true values of \eqn{\delta} and \eqn{\theta} (if provided).
 }
}
\description{
This function implements the Bayesian Surrogate Evaluation Test (BSET)
as proposed by \insertCite{carlotti2026bayesian;textual}{BSET}. When \code{X}
is \code{NULL} (the default), the model is fit without covariates; when \code{X}
is provided, a multivariate regression model is used to adjust for baseline
covariates. In both cases the function fits a Bayesian model using Stan to
generate posterior samples for the parameters of interest, which are then
used to conduct a Bayesian hypothesis test for evaluating the validity of
the surrogate marker. A frequentist test is also performed for comparison.
}
\details{
\strong{Without covariates} (\code{X = NULL}), the Bayesian model is:
\deqn{(Y_i, S_i) = \begin{cases}
P_{1i}, & \text{if } Z_i = 1 \\
P_{0i}, & \text{if } Z_i = 0
\end{cases}, \quad i = 1, \ldots, n,}
\deqn{P_i \overset{\text{ind.}}{\sim} \mathcal{N}_4(\mu, \Sigma), \quad i = 1, \ldots, n,}
\deqn{\mu \sim \mathcal{N}_4(\mu_0, \Sigma_0),}
\deqn{\Sigma = \text{diag}(\sigma_{1:4}) \, \Omega \, \text{diag}(\sigma_{1:4}),}
\deqn{\sigma_k \sim \text{Half-Normal}(0, s_k), \quad k = 1, \ldots, 4,}
\deqn{\Omega \sim \text{LKJ}(\tau).}

\strong{With covariates} (\code{X} provided), the Bayesian model is:
\deqn{P_i \overset{\text{ind.}}{\sim} \mathcal{N}_4(B X_i, \Sigma), \quad i = 1, \ldots, n,}
\deqn{B = \begin{bmatrix}
\beta_{1} & \beta_{2} & \beta_{3} & \beta_{4} \\
\end{bmatrix}^\top,}
\deqn{\beta_{k} \sim \mathcal{N}_d (\mu_{\beta}, \Sigma_{\beta}), \quad k = 1, \ldots, 4,}
with \eqn{\Sigma}, \eqn{\sigma_k}, and \eqn{\Omega} as above.

This is a primary user-facing function of the package and includes working examples below.
}
\examples{
# Generate data from the perfect surrogate setting of Parast et al. (2024)
set.seed(123)
data_no_X <- DGP_no_X(
  n = 100,
  p = 0.5,
  mu_star = c(6, 6, 2.5, 2.5),
  Sigma_star = kronecker(diag(2), matrix(c(3, 3, 3, 3.1), 2, 2)),
  model = "Gaussian"
)

# Prepare the data frame
df_no_X <- data.frame(
  Y = data_no_X$P_observed[, "Y"],
  S = data_no_X$P_observed[, "S"],
  Z = data_no_X$Z
)

# Run BSET without covariates (requires Stan compilation, ~3 minutes)
\donttest{
result_no_X <- BSET(
  data = df_no_X,
  Y = "Y",
  S = "S",
  Z = "Z",
  seed = 123,
  n_chains = 2,
  n_iter = 500
)
}

# Generate data from the setting of Carlotti and Parast (2026) with a binary covariate
set.seed(123)
data_X <- DGP_X_binary(
  n = 100,
  p = 0.5,
  q = 0.5,
  mu_0 = c(5, 5, 0, 0),
  mu_1 = c(5, -5, 0, -10),
  Sigma_0 = kronecker(diag(2), matrix(c(1, 1, 1, 2), 2, 2)),
  Sigma_1 = kronecker(diag(2), matrix(c(1, 1, 1, 2), 2, 2))
)

# Prepare the data frame
df_X <- data.frame(
  Y = data_X$P_observed[, "Y"],
  S = data_X$P_observed[, "S"],
  Z = data_X$Z,
  X = data_X$X
)

# Run BSET with covariates (requires Stan compilation, ~3 minutes)
\donttest{
result_X <- BSET(
  data = df_X,
  Y = "Y",
  S = "S",
  Z = "Z",
  X = "X",
  seed = 123,
  n_chains = 2,
  n_iter = 500
)
}
}
\references{
\insertRef{carlotti2026bayesian}{BSET}

\insertRef{parast2024rank}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DGP_no_X.R
\name{DGP_no_X}
\alias{DGP_no_X}
\title{Data Generating Process without Baseline Covariates}
\usage{
DGP_no_X(
  n,
  p,
  mu_star = NULL,
  Sigma_star = NULL,
  model = c("Gaussian", "misspecified")
)
}
\arguments{
\item{n}{Integer. Total sample size.}

\item{p}{Numeric. Probability of being assigned to the treatment group (Z=1).}

\item{mu_star}{Numeric vector. The mean vector for \eqn{P}. Required if \code{model = "Gaussian"}.}

\item{Sigma_star}{Matrix. The covariance matrix for \eqn{P}. Required if \code{model = "Gaussian"}.}

\item{model}{Character. The type of data generation: \code{"Gaussian"} 
or \code{"misspecified"}.}
}
\value{
A list containing:
\itemize{
  \item \code{Z}: Treatment assignment vector.
  \item \code{n1}: Number of treated units.
  \item \code{n0}: Number of control units.
  \item \code{P}: Full matrix of potential outcomes.
  \item \code{P_observed}: Observed outcomes \eqn{(Y, S)} corresponding to the assigned treatment \eqn{Z}.
  \item \code{P_unobserved}: Counterfactual outcomes under the opposite treatment.
}
This function is useful for generating synthetic data to test or explore
the method, for instance to verify the behavior of \code{BSET_no_X} under
known simulation settings.
}
\description{
This function generates potential outcomes from the simulation settings
described in \insertCite{parast2024rank;textual}{BSET}. It creates a dataset of potential outcomes
\deqn{P = (Y_1, S_1, Y_0, S_0)} and observed outcomes 
\deqn{P_{observed} = (Y, S)} based on a random treatment assignment \eqn{Z}.
}
\details{
The function supports two types of data-generating processes:
\itemize{
  \item \strong{Gaussian model:} Potential outcomes are drawn from a 
  multivariate normal distribution:
  \deqn{P \sim \mathcal{N}_{4}(\mu^{*}, \Sigma^{*}).}
  \item \strong{Non-linear model:} Potential outcomes for the surrogate are generated from a non-Gaussian
  distribution, and the potential outcomes for the primary outcome are generated from a non-linear function of the surrogate plus non-Gaussian noise.
}
}
\examples{
set.seed(123)
data <- DGP_no_X(
  n = 100,
  p = 0.5,
  mu_star = c(6, 6, 2.5, 2.5),
  Sigma_star = kronecker(diag(2), matrix(c(3, 3, 3, 3.1), 2, 2)),
  model = "Gaussian"
)
}
\references{
\insertRef{parast2024rank}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DGP_X.R
\name{DGP_X_Gaussian}
\alias{DGP_X_Gaussian}
\title{Data Generating Process with a Gaussian Covariate}
\usage{
DGP_X_Gaussian(n, p, beta, Sigma, m, s)
}
\arguments{
\item{n}{Integer. Total sample size.}

\item{p}{Numeric. Probability of being assigned to the treatment group \eqn{(Z=1)}.}

\item{beta}{Numeric vector. Coefficients for the linear function of the covariate \eqn{X}.}

\item{Sigma}{Matrix. Covariance matrix for the potential outcomes.}

\item{m}{Numeric. Mean of the Gaussian covariate \eqn{X}.}

\item{s}{Numeric. Standard deviation of the Gaussian covariate \eqn{X}.}
}
\value{
A list containing:
\itemize{
 \item \code{X}: The Gaussian covariate vector.
 \item \code{Z}: Treatment assignment vector.
 \item \code{n1}: Number of treated units.
 \item \code{n0}: Number of control units.
 \item \code{P}: Full matrix of potential outcomes.
 \item \code{P_observed}: Observed outcomes \eqn{(Y, S)} corresponding to the assigned treatment \eqn{Z}.
 \item \code{P_unobserved}: Counterfactual outcomes under the opposite treatment.
}
This function is useful for generating synthetic data to test or explore
the method, for instance to verify the behavior of \code{BSET_X} under
known simulation settings.
}
\description{
This function generates potential outcomes from a data generating process
similar to the one described in \insertCite{parast2024rank;textual}{BSET}, but with the addition
of a Gaussian covariate X. It creates a dataset of potential outcomes
\deqn{P = (Y_1, S_1, Y_0, S_0)} and observed outcomes
\deqn{P_{observed} = (Y, S)} based on a random treatment assignment \eqn{Z}.
}
\details{
The potential outcomes are generated from a multivariate normal
distribution with mean vector and covariance matrix that depend on the
value of \eqn{X}. Specifically, the mean vector is a linear function of \eqn{X}:
\deqn{\mu(X) = x \cdot (\beta_{Y1}, \beta_{S1}, \beta_{Y0}, \beta_{S0})^T,}
and the covariance matrix is constant across values of \eqn{X}:
\deqn{\Sigma(X) = \Sigma.}
}
\examples{
set.seed(123)
data <- DGP_X_Gaussian(
  n = 100,
  p = 0.5,
  beta = c(1, 7, 0, 6),
  Sigma = 0.5 * diag(4),
  m = 3,
  s = 1
)
}
\references{
\insertRef{carlotti2026bayesian}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_theta.R
\name{compute_theta}
\alias{compute_theta}
\title{Monte Carlo Computation of the Parameter \eqn{\theta} from Carlotti and Parast (2026)}
\usage{
compute_theta(MC_data)
}
\arguments{
\item{MC_data}{A list containing:
\itemize{
  \item \code{P}: A matrix or data frame of potential outcomes with columns 
    "Y1", "Y0", "S1", and "S0".
}}
}
\value{
A list containing the true values:
\itemize{
  \item \code{V_Y}: The Monte Carlo estimate of \eqn{P(Y_{1i} > Y_{0i})} computed on \code{P}.
  \item \code{V_S}: The Monte Carlo estimate of \eqn{P(S_{1i} > S_{0i})} computed on \code{P}.
  \item \code{theta}: The difference \code{V_Y} - \code{V_S}.
}
}
\description{
This function implements a Monte Carlo approach to estimate the parameter
\eqn{\theta} from \insertCite{carlotti2026bayesian;textual}{BSET}. This parameter represents the
difference in treatment effects between the primary and surrogate outcomes,
both measured using the probability that the treated outcome is larger
than the control outcome.
}
\details{
The function processes data from a chosen data generating process,
computing the sample probabilities for both the primary outcome \eqn{Y} and
the surrogate \eqn{S}:
\deqn{\hat{V}_Y = \frac{1}{n} \sum\limits^{n}_{i=1} I(Y_{1i} > Y_{0i}),}
\deqn{\hat{V}_S = \frac{1}{n} \sum\limits^{n}_{i=1} I(S_{1i} > S_{0i}).}
Then, it calculates
\deqn{\hat{\theta} = \hat{V}_Y - \hat{V}_S.}
This function is generally not intended to be called directly by the user
and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
}
\references{
\insertRef{carlotti2026bayesian}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DGP_X.R
\name{DGP_X_binary}
\alias{DGP_X_binary}
\title{Data Generating Process with a Binary Covariate}
\usage{
DGP_X_binary(n, p, q, mu_0, mu_1, Sigma_0, Sigma_1)
}
\arguments{
\item{n}{Integer. Total sample size.}

\item{p}{Numeric. Probability of being assigned to the treatment group \eqn{(Z=1)}.}

\item{q}{Numeric. Probability of the binary covariate X being 1.}

\item{mu_0}{Numeric vector. Mean vector for \eqn{P} when \eqn{X=0}.}

\item{mu_1}{Numeric vector. Mean vector for \eqn{P} when \eqn{X=1}.}

\item{Sigma_0}{Matrix. Covariance matrix for \eqn{P} when \eqn{X=0}.}

\item{Sigma_1}{Matrix. Covariance matrix for \eqn{P} when \eqn{X=1}.}
}
\value{
A list containing:
\itemize{
  \item \code{X}: The binary covariate vector.
  \item \code{n_X1}: Number of units with \eqn{X=1}.
  \item \code{n_X0}: Number of units with \eqn{X=0}.
  \item \code{Z}: Treatment assignment vector.
  \item \code{n1}: Number of treated units.
  \item \code{n0}: Number of control units.
  \item \code{P}: Full matrix of potential outcomes.
  \item \code{P_observed}: Observed outcomes \eqn{(Y, S)} corresponding to the assigned treatment \eqn{Z}.
  \item \code{P_unobserved}: Counterfactual outcomes under the opposite treatment.
}
This function is useful for generating synthetic data to test or explore
the method, for instance to verify the behavior of \code{BSET_X} under
known simulation settings.
}
\description{
This function generates potential outcomes from a data generating process
similar to the one described in \insertCite{parast2024rank;textual}{BSET}, but with the addition
of a binary covariate X. It creates a dataset of potential outcomes
\deqn{P = (Y_1, S_1, Y_0, S_0)} and observed outcomes
\deqn{P_{observed} = (Y, S)} based on a random treatment assignment \eqn{Z}.
}
\details{
The potential outcomes are generated from multivariate normal
distributions with different mean vectors and covariance matrices depending
on the value of \eqn{X}. Specifically:
\deqn{P \mid X = 0 \sim \mathcal{N}_{4}(\mu^{0}, \Sigma^{0}), \\
P \mid X = 1 \sim \mathcal{N}_{4}(\mu^{1}, \Sigma^{1}).}
}
\examples{
set.seed(123)
data <- DGP_X_binary(
  n = 100,
  p = 0.5,
  q = 0.5,
  mu_0 = c(5, 5, 0, 0),
  mu_1 = c(5, -5, 0, -10),
  Sigma_0 = kronecker(diag(2), matrix(c(1, 1, 1, 2), 2, 2)),
  Sigma_1 = kronecker(diag(2), matrix(c(1, 1, 1, 2), 2, 2))
)
}
\references{
\insertRef{carlotti2026bayesian}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_delta.R
\name{compute_delta}
\alias{compute_delta}
\title{Monte Carlo Computation of the Parameter \eqn{\delta} from Parast et al. (2024)}
\usage{
compute_delta(MC_data)
}
\arguments{
\item{MC_data}{A list containing:
\itemize{
  \item \code{P_observed}: A data frame or matrix with columns "Y" and "S".
  \item \code{Z}: Treatment assignment vector.
  \item \code{n1}: Number of treated units.
  \item \code{n0}: Number of control units.
}}
}
\value{
A list containing:
\itemize{
  \item \code{U_Y}: Mann-Whitney U statistic for the primary outcome Y computed on \code{P_observed}.
  \item \code{U_S}: Mann-Whitney U statistic for the surrogate S computed on \code{P_observed}.
  \item \code{delta}: The difference \code{U_Y} - \code{U_S}.
}
}
\description{
This function implements a Monte Carlo approach to estimate the parameter
\eqn{\delta} from \insertCite{parast2024rank;textual}{BSET}. This parameter represents the
difference in treatment effects between the primary and surrogate outcomes,
both measured using the Mann-Whitney statistic.
}
\details{
The function processes data from a chosen data generating process,
computing the Mann-Whitney U statistic for both the primary outcome \eqn{Y}
and the surrogate \eqn{S}:
\deqn{\hat{U}_Y = \frac{1}{n_1 n_0} \sum\limits_{i:Z_i=1} \sum\limits_{j:Z_j=0} I(Y_i > Y_j),}
\deqn{\hat{U}_S = \frac{1}{n_1 n_0} \sum\limits_{i:Z_i=1} \sum\limits_{j:Z_j=0} I(S_i > S_j).}
Then, it calculates
\deqn{\hat{\delta} = \hat{U}_Y - \hat{U}_S.}
This function is generally not intended to be called directly by the user
and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
}
\references{
\insertRef{parast2024rank}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{estimands_Parast_et_al_2024}
\alias{estimands_Parast_et_al_2024}
\title{True estimands for Parast et al. (2024)}
\format{
A data frame with 4 rows and 7 columns:
\describe{
  \item{setting}{The index of the simulation setting.}
  \item{U_Y_MC}{Numeric vector of Monte Carlo estimates.}
  \item{U_S_MC}{Numeric vector of Monte Carlo estimates.}
  \item{delta_MC}{Numeric vector of Monte Carlo estimates.}
  \item{V_Y_MC}{Numeric vector of Monte Carlo estimates.}
  \item{V_S_MC}{Numeric vector of Monte Carlo estimates.}
  \item{theta_MC}{Numeric vector of Monte Carlo estimates.}
}
}
\source{
Computed using the function \code{compute_estimands_Parast_et_al_2024(1000000)}.
}
\usage{
estimands_Parast_et_al_2024
}
\description{
A dataset containing the Monte Carlo estimates of the parameters of interest
for the simulation settings considered in Parast et al. (2024).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_estimands_Parast_et_al_2024.R
\name{compute_estimands_Parast_et_al_2024}
\alias{compute_estimands_Parast_et_al_2024}
\title{Monte Carlo Computation of the Estimands for the Simulation Study in Parast et al. (2024)}
\usage{
compute_estimands_Parast_et_al_2024(MC_samples)
}
\arguments{
\item{MC_samples}{Integer. The number of Monte Carlo samples to generate per setting.}
}
\value{
A data frame containing the Monte Carlo estimates for each setting:
\itemize{
  \item \code{setting}: The index of the simulation setting.
  \item \code{U_Y_MC}, \code{U_S_MC}, \code{delta_MC}: Parameters of interest from \insertCite{parast2024rank;textual}{BSET}.
  \item \code{V_Y_MC}, \code{V_S_MC}, \code{theta_MC}: Parameters of interest from \insertCite{carlotti2026bayesian;textual}{BSET}.
}
}
\description{
This function iterates through the four simulation settings defined in Parast
et al. (2024) and estimates the true values of \eqn{U_Y}, \eqn{U_S},
\eqn{\delta}, \eqn{V_Y}, \eqn{V_S}, and \eqn{\theta} using a Monte Carlo
dataset generated according to the specified data-generating processes.
}
\details{
The settings are defined as follows:
\itemize{
  \item Setting 1: \strong{Useless surrogate (Gaussian model)}
    \deqn{Y_1 \sim \mathcal{N}(5, 3), \quad Y_0 \sim \mathcal{N}(3, 3),}
    \deqn{S_1 \sim \mathcal{N}(2/3, 1), \quad S_0 \sim \mathcal{N}(2/3, 1).}
  \item Setting 2: \strong{Perfect surrogate (Gaussian model)}
    \deqn{Y_1 \sim \mathcal{N}(6, 3), \quad Y_0 \sim \mathcal{N}(5/2, 3),}
    \deqn{S_1 = Y_1 + \mathcal{N}(0, 1/10), \quad S_0 = Y_0 + \mathcal{N}(0, 1/10).}
  \item Setting 3: \strong{Imperfect surrogate (Gaussian model)}
    \deqn{S_1 \sim \mathcal{N}(5, 3), \quad S_0 \sim \mathcal{N}(3, 3),}
    \deqn{Y_1 = S_1 + \mathcal{N}(1.5, 0.6), \quad Y_0 = S_0 + \mathcal{N}(0, 0.6).}
  \item Setting 4: \strong{Misspecified model (non-Gaussian model)}
    \deqn{S_1 \sim \exp(\mathcal{N}(2.5, 1.5)), \quad S_0 \sim \exp(\mathcal{N}(0.5, 1.5)),}
    \deqn{Y_1 = 2 + 6/5 \sqrt{S_1} + 3/10 \exp(S_1 / 500) + \exp(\mathcal{N}(0, 0.3)),}
    \deqn{Y_0 = 4/5 \sqrt{S_0} + 1/5 \exp(S_0 / 50) + \exp(\mathcal{N}(0, 0.3)).}
}
This function is generally not intended to be called directly by the user.
It is provided as a utility for computing the true parameter values for the
simulation settings described in \insertCite{parast2024rank;textual}{BSET}.
}
\references{
\insertRef{parast2024rank}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{estimands_Carlotti_and_Parast_2026}
\alias{estimands_Carlotti_and_Parast_2026}
\title{True estimands for Carlotti and Parast (2026)}
\format{
A data frame with 2 rows and 7 columns:
\describe{
  \item{setting}{The index of the simulation setting.}
  \item{U_Y_MC}{Monte Carlo estimate of \eqn{U_Y = P(Y_{1i} > Y_{0j})}.}
  \item{U_S_MC}{Monte Carlo estimate of \eqn{U_S = P(S_{1i} > S_{0j})}.}
  \item{delta_MC}{Monte Carlo estimate of \eqn{\delta = U_Y - U_S}.}
  \item{V_Y_MC}{Monte Carlo estimate of \eqn{V_Y = P(Y_{1i} > Y_{0i})}.}
  \item{V_S_MC}{Monte Carlo estimate of \eqn{V_S = P(S_{1i} > S_{0i})}.}
  \item{theta_MC}{Monte Carlo estimate of \eqn{\theta = V_Y - V_S}.}
}
}
\source{
Computed using the function \code{compute_estimands_Carlotti_and_Parast_2026(1000000)}.
}
\usage{
estimands_Carlotti_and_Parast_2026
}
\description{
A dataset containing the Monte Carlo estimates of the parameters of interest
for the two simulation settings considered in Carlotti and Parast (2026):
setting 1 (binary covariate) and setting 2 (Gaussian covariate).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_V_S_star.R
\name{compute_V_S_star}
\alias{compute_V_S_star}
\title{Compute \eqn{v_S} from Carlotti and Parast (2026)}
\usage{
compute_V_S_star(
  n,
  alpha = 0.05,
  beta = 0.2,
  V_S_zero = 0.5,
  a = 1,
  b = 1,
  BF_alternative = "greater",
  root_tolerance = 1e-16
)
}
\arguments{
\item{n}{Integer. Sample size.}

\item{alpha}{Numeric. Type I error rate (default is 0.05).}

\item{beta}{Numeric. Type II error rate (default is 0.2).}

\item{V_S_zero}{Numeric. The hypothesized value of the surrogate's treatment effect under the null hypothesis (default is 0.5).}

\item{a}{Numeric. First shape parameter alpha for the Beta prior (default is 1).}

\item{b}{Numeric. Second shape parameter beta for the Beta prior (default is 1).}

\item{BF_alternative}{Character. The type of alternative hypothesis: either \code{"two_sided"} or \code{"greater"}.}

\item{root_tolerance}{Numeric. Tolerance level for the root-finding algorithm (default is 1e-16).}
}
\value{
A list containing:
\itemize{
  \item \code{BF_alpha}: The critical value of the Bayes factor corresponding to the specified alpha level.
  \item \code{V_S_star}: The value of \eqn{v_S} that satisfies the power constraint for the surrogate validation test.
}
}
\description{
This function determines the value \eqn{v_S} that is used to compute the
surrogate validation threshold \eqn{\eta} from \insertCite{carlotti2026bayesian;textual}{BSET}:
\deqn{\eta = \max \{v_Y - v_S, 0\},}
where \eqn{v_Y} is the hypothesized value of the treatment effect on the
primary outcome (typically set equal to the estimate computed on the
available data) and \eqn{v_S} is the value that satisfies the following power
constraint:
\deqn{P(\text{BF}_n \geq \text{BF}_{n, \alpha} \; | \; V_S = v_S) = 1 - \beta,}
where \eqn{\text{BF}_{n, \alpha}} is the \eqn{(1 - \alpha)} quantile of the
Bayes factor distribution under the null hypothesis \eqn{V_S = V^0_{S}}, and \eqn{1 - \beta} is the desired power of the
test. The function computes the distribution of the Bayes factor under the null
hypothesis, derives the critical value \eqn{\text{BF}_{n, \alpha}}, and then
uses a root-finding algorithm to solve for the value of \eqn{v_S} that
satisfies the power constraint.
This function is generally not intended to be called directly by the user
and is instead used internally within \code{BSET_no_X} and \code{BSET_X}.
}
\references{
\insertRef{carlotti2026bayesian}{BSET}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{Parast_et_al_2024_simulations_grid}
\alias{Parast_et_al_2024_simulations_grid}
\title{Simulation grid for Parast et al. (2024)}
\format{
A data frame with multiple columns:
\describe{
  \item{setting}{The index of the simulation setting.}
  \item{simulation}{The index of the simulation run.}
  \item{n_sample}{The sample size used.}
  \item{n_chains}{The number of MCMC chains used.}
  \item{n_iterations}{The number of MCMC iterations.}
  \item{n_simulations}{The total number of simulations.}
  \item{timestamp}{The timestamp of execution.}
  \item{seed}{The random seed used.}
  \item{BF_alternative}{The alternative hypothesis used for the Bayes factor.}
  \item{Bayesian_epsilon}{The threshold for the Bayesian test.}
  \item{frequentist_epsilon}{The threshold for the frequentist test.}
  \item{Bayesian_CI_upper}{The upper bound of the Bayesian credible interval.}
  \item{frequentist_CI_upper}{The upper bound of the frequentist confidence interval.}
  \item{Bayesian_coverage}{Logical. Indicates if the true value is in the credible interval.}
  \item{frequentist_coverage}{Logical. Indicates if the true value is in the confidence interval.}
  \item{Bayesian_power}{Logical. Indicates if the Bayesian test rejected the null.}
  \item{frequentist_power}{Logical. Indicates if the frequentist test rejected the null.}
}
}
\source{
Generated using the code in the \code{simulations} folder of the
  BSET GitHub repository (\url{https://github.com/PietroCarlotti/BSET}).
}
\usage{
Parast_et_al_2024_simulations_grid
}
\description{
A dataset containing the grid of simulation results for Parast et al. (2024).
}
\keyword{datasets}
